pub fn decode_request_prelude(
frame: &[u8],
) -> Result<Option<(RequestPrelude<'_>, usize)>, FrameError>Expand description
Incrementally decodes the method and typed context at an operation-stream start.
pub fn decode_request_prelude(
frame: &[u8],
) -> Result<Option<(RequestPrelude<'_>, usize)>, FrameError>Incrementally decodes the method and typed context at an operation-stream start.