pub fn encode_request_prelude(
method: &str,
context: &CallContext,
) -> Result<Vec<u8>, FrameError>Expand description
Encodes the method and typed context that precede a streaming body.
pub fn encode_request_prelude(
method: &str,
context: &CallContext,
) -> Result<Vec<u8>, FrameError>Encodes the method and typed context that precede a streaming body.