#[repr(i32)]pub enum HostedWitnessKeyRole {
Unspecified = 0,
HostWitness = 1,
}Expand description
Deliberately no JOB arm. Also reject any member public key present in the receiver/issuer’s persistent job-key associations (including old job keys).
Variants
Implementations
Sourceimpl HostedWitnessKeyRole
impl HostedWitnessKeyRole
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of HostedWitnessKeyRole.
Sourcepub fn from_i32(value: i32) -> Option<HostedWitnessKeyRole>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<HostedWitnessKeyRole>
Use the TryFrom<i32> implementation instead
Converts an i32 to a HostedWitnessKeyRole, or None if value is not a valid variant.
Sourceimpl HostedWitnessKeyRole
impl HostedWitnessKeyRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.