#[repr(i32)]pub enum MandatoryProtocolFeature {
Unspecified = 0,
ImportAuthorityHostWitnessV1 = 1,
}Expand description
Semantic support, independent of package/release version. Missing/unknown mandatory features reject before staging, signatures or durable mutation.
Variants
Implementations
Sourceimpl MandatoryProtocolFeature
impl MandatoryProtocolFeature
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of MandatoryProtocolFeature.
Sourcepub fn from_i32(value: i32) -> Option<MandatoryProtocolFeature>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<MandatoryProtocolFeature>
Use the TryFrom<i32> implementation instead
Converts an i32 to a MandatoryProtocolFeature, or None if value is not a valid variant.
Sourceimpl MandatoryProtocolFeature
impl MandatoryProtocolFeature
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.