pub struct AccountBillingLock {
pub reason: i32,
pub locked_at: Option<Timestamp>,
pub delete_after: Option<Timestamp>,
pub used_bytes: u64,
pub cap_bytes: u64,
pub allowed_actions: Vec<i32>,
}Expand description
Current account billing restriction. used_bytes and cap_bytes are retained logical bytes from the same authoritative storage ledger used to apply the Free-plan gate; they are decimal byte counts, not physical/object-store size.
Fields
reason: i32locked_at: Option<Timestamp>delete_after: Option<Timestamp>used_bytes: u64cap_bytes: u64allowed_actions: Vec<i32>Implementations
Sourceimpl AccountBillingLock
impl AccountBillingLock
Sourcepub fn reason(&self) -> AccountBillingLockReason
pub fn reason(&self) -> AccountBillingLockReason
Returns the enum value of reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: AccountBillingLockReason)
pub fn set_reason(&mut self, value: AccountBillingLockReason)
Sets reason to the provided enum value.
Sourcepub fn allowed_actions(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AccountBillingLockAllowedAction>> ⓘ
pub fn allowed_actions( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AccountBillingLockAllowedAction>> ⓘ
Returns an iterator which yields the valid enum values contained in allowed_actions.
Sourcepub fn push_allowed_actions(&mut self, value: AccountBillingLockAllowedAction)
pub fn push_allowed_actions(&mut self, value: AccountBillingLockAllowedAction)
Appends the provided enum value to allowed_actions.