#[repr(i32)]pub enum ActorPresenceStatus {
Unspecified = 0,
Active = 1,
Abandoned = 2,
Complete = 3,
Merged = 4,
}Expand description
Actor lifecycle status emitted by the Heddle actor registry.
Variants
Implementations
Sourceimpl ActorPresenceStatus
impl ActorPresenceStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ActorPresenceStatus.
Sourcepub fn from_i32(value: i32) -> Option<ActorPresenceStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ActorPresenceStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ActorPresenceStatus, or None if value is not a valid variant.
Sourceimpl ActorPresenceStatus
impl ActorPresenceStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.