#[repr(i32)]pub enum AuthorizationExistence {
Unspecified = 0,
Disclose = 1,
Hide = 2,
PlannedUndecided = 3,
}Variants
Unspecified = 0
Disclose = 1
Hide = 2
PlannedUndecided = 3
The service is planned, but its authorization policy has not been decided. This value is invalid for shipped services.
Implementations
Sourceimpl AuthorizationExistence
impl AuthorizationExistence
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of AuthorizationExistence.
Sourcepub fn from_i32(value: i32) -> Option<AuthorizationExistence>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AuthorizationExistence>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AuthorizationExistence, or None if value is not a valid variant.
Sourceimpl AuthorizationExistence
impl AuthorizationExistence
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.