#[repr(i32)]pub enum AuthorizationRole {
Unspecified = 0,
None = 1,
CallerBound = 2,
ResourceReader = 3,
ResourceWriter = 4,
ResourceAdministrator = 5,
CallerOrResourceAdministrator = 6,
GlobalAdministrator = 7,
PlannedUndecided = 8,
ResourceMaintainer = 9,
ResourceOwner = 10,
}Variants
Unspecified = 0
None = 1
CallerBound = 2
ResourceReader = 3
ResourceWriter = 4
ResourceAdministrator = 5
CallerOrResourceAdministrator = 6
GlobalAdministrator = 7
PlannedUndecided = 8
The service is planned, but its authorization policy has not been decided. This value is invalid for shipped services.
ResourceMaintainer = 9
Resource roles preserve Weft’s hosted-role guard vocabulary. These values are appended so existing enum numbers remain wire-compatible.
ResourceOwner = 10
Implementations
Sourceimpl AuthorizationRole
impl AuthorizationRole
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of AuthorizationRole.
Sourcepub fn from_i32(value: i32) -> Option<AuthorizationRole>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AuthorizationRole>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AuthorizationRole, or None if value is not a valid variant.
Sourceimpl AuthorizationRole
impl AuthorizationRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.