#[repr(i32)]pub enum CapabilityArea {
Show 15 variants
Unspecified = 0,
RunHistoryDetails = 1,
StateComparison = 2,
BranchProtection = 3,
WorkspaceManagement = 4,
ReviewDecisions = 5,
Synchronization = 6,
SpoolAdministration = 7,
RepositoryInspection = 8,
IdentityAndCredentials = 9,
Collaboration = 10,
AttentionFeed = 11,
PullRequestReview = 12,
Search = 13,
AsynchronousOperations = 14,
}Variants
Unspecified = 0
RunHistoryDetails = 1
StateComparison = 2
BranchProtection = 3
WorkspaceManagement = 4
ReviewDecisions = 5
Synchronization = 6
SpoolAdministration = 7
RepositoryInspection = 8
IdentityAndCredentials = 9
Collaboration = 10
AttentionFeed = 11
PullRequestReview = 12
Search = 13
AsynchronousOperations = 14
Implementations
Sourceimpl CapabilityArea
impl CapabilityArea
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.