#[repr(i32)]pub enum ChangeClassification {
Unspecified = 0,
Logic = 1,
WhitespaceOnly = 2,
ImportsOnly = 3,
CommentsOnly = 4,
FormattingOnly = 5,
Mixed = 6,
Unclassified = 7,
}Expand description
Semantic change classification emitted by the repository diff analyzer. UNCLASSIFIED is the legacy “modified” fallback when no finer result exists.
Variants
Unspecified = 0
Logic = 1
WhitespaceOnly = 2
ImportsOnly = 3
CommentsOnly = 4
FormattingOnly = 5
Mixed = 6
Unclassified = 7
Implementations
Sourceimpl ChangeClassification
impl ChangeClassification
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ChangeClassification.
Sourcepub fn from_i32(value: i32) -> Option<ChangeClassification>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ChangeClassification>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ChangeClassification, or None if value is not a valid variant.
Sourceimpl ChangeClassification
impl ChangeClassification
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.