#[repr(i32)]pub enum ChangeImportance {
Unspecified = 0,
Noise = 1,
Low = 2,
Medium = 3,
High = 4,
}Expand description
Review importance emitted by the repository diff analyzer.
Variants
Implementations
Sourceimpl ChangeImportance
impl ChangeImportance
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ChangeImportance.
Sourcepub fn from_i32(value: i32) -> Option<ChangeImportance>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ChangeImportance>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ChangeImportance, or None if value is not a valid variant.
Sourceimpl ChangeImportance
impl ChangeImportance
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.