#[repr(i32)]pub enum CheckKind {
Unspecified = 0,
FileReviewed = 1,
RiskSignalAck = 2,
}Expand description
Kind of review-progress check (weft#482).
Variants
Unspecified = 0
FileReviewed = 1
per-file checkmark; check_ref = file path
RiskSignalAck = 2
per-risk-signal ack; check_ref = signal id
Implementations
Sourceimpl CheckKind
impl CheckKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.