#[repr(i32)]pub enum DeviceAuthorizationStatus {
Unspecified = 0,
Pending = 1,
Approved = 2,
Expired = 3,
}Expand description
Device-authorization lifecycle from the identity authorization model.
Variants
Implementations
Sourceimpl DeviceAuthorizationStatus
impl DeviceAuthorizationStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of DeviceAuthorizationStatus.
Sourcepub fn from_i32(value: i32) -> Option<DeviceAuthorizationStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<DeviceAuthorizationStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a DeviceAuthorizationStatus, or None if value is not a valid variant.
Sourceimpl DeviceAuthorizationStatus
impl DeviceAuthorizationStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.