#[repr(i32)]pub enum DiffLineKind {
Unspecified = 0,
Context = 1,
Added = 2,
Removed = 3,
}Expand description
Diff line vocabulary emitted by the repository diff model.
Variants
Implementations
Sourceimpl DiffLineKind
impl DiffLineKind
Sourceimpl DiffLineKind
impl DiffLineKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.