#[repr(i32)]pub enum DigestCadence {
Unspecified = 0,
Off = 1,
Hourly = 2,
Daily = 3,
Weekly = 4,
}Expand description
Cadence of the recipient’s digest roll-up. OFF disables digests (DIGEST-routed notifications then never leave the in-app inbox on a schedule).
Variants
Implementations
Sourceimpl DigestCadence
impl DigestCadence
Sourceimpl DigestCadence
impl DigestCadence
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.