#[repr(i32)]pub enum DiscussionKind {
Unspecified = 0,
CodeAnchored = 1,
Coordination = 2,
Imported = 3,
}Expand description
The subject a discussion is anchored to. Servers return an explicit kind for newly stored discussions. UNSPECIFIED preserves the pre-kind contract and is interpreted as CODE_ANCHORED when opening or reading a discussion.
Variants
Unspecified = 0
CodeAnchored = 1
A discussion about a code symbol. This is the existing/default behavior.
Coordination = 2
A thread-only mailbox for capacity, handoff, and meta-chatter. It is queryable but inert: the discussion never controls or affects work.
Imported = 3
A discussion imported from an external source (e.g. an adopted repository).
Implementations
Sourceimpl DiscussionKind
impl DiscussionKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.