#[repr(i32)]pub enum DiscussionSeverity {
Unspecified = 0,
Informational = 1,
Blocking = 2,
}Expand description
Whether an open discussion is informational or prevents a merge.
Variants
Implementations
Sourceimpl DiscussionSeverity
impl DiscussionSeverity
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of DiscussionSeverity.
Sourcepub fn from_i32(value: i32) -> Option<DiscussionSeverity>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<DiscussionSeverity>
Use the TryFrom<i32> implementation instead
Converts an i32 to a DiscussionSeverity, or None if value is not a valid variant.
Sourceimpl DiscussionSeverity
impl DiscussionSeverity
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.