ErrorReason

Enum ErrorReason 

#[repr(i32)]
pub enum ErrorReason {
Show 24 variants Unspecified = 0, CredentialMissing = 100, CredentialExpired = 101, CredentialRevoked = 102, ProofInvalid = 103, ScopeMissing = 200, RoleInsufficient = 201, PolicyDenied = 202, PlanLimit = 203, ResourceNotFound = 300, ResourceGone = 301, FieldInvalid = 400, FieldRequired = 401, ChangeIdAmbiguous = 402, LifecycleState = 500, OperationIdReused = 501, VersionConflict = 502, AlreadyExists = 503, RateLimited = 600, QuotaExceeded = 601, CursorInvalid = 602, Transient = 900, Internal = 901, Unimplemented = 902,
}

Variants



Unspecified = 0



CredentialMissing = 100

Authentication (1xx)



CredentialExpired = 101



CredentialRevoked = 102



ProofInvalid = 103



ScopeMissing = 200

Authorization (2xx)



RoleInsufficient = 201



PolicyDenied = 202



PlanLimit = 203



ResourceNotFound = 300

Existence (3xx)



ResourceGone = 301



FieldInvalid = 400

Request validity (4xx)



FieldRequired = 401



ChangeIdAmbiguous = 402



LifecycleState = 500

Preconditions & conflicts (5xx)



OperationIdReused = 501



VersionConflict = 502



AlreadyExists = 503



RateLimited = 600

Flow control (6xx). RATE_LIMITED / QUOTA_EXCEEDED are retryable; CURSOR_INVALID is a client-fix (restart from a valid cursor), not retryable.



QuotaExceeded = 601



CursorInvalid = 602



Transient = 900

Server (9xx)



Internal = 901



Unimplemented = 902

Implementations

Source

impl ErrorReason

pub const fn is_valid(value: i32) -> bool

Returns true if value is a variant of ErrorReason.

pub fn from_i32(value: i32) -> Option<ErrorReason>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a ErrorReason, or None if value is not a valid variant.

Source

impl ErrorReason

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.

Source

impl ErrorReason

pub fn retryable(&self) -> bool

Returns whether callers may retry without first correcting the request.