#[repr(i32)]pub enum FeedItemResolution {
Unspecified = 0,
Pending = 1,
Dismissed = 2,
ActedOn = 3,
AutoResolved = 4,
Expired = 5,
Pinned = 6,
}Variants
Unspecified = 0
Pending = 1
Dismissed = 2
ActedOn = 3
AutoResolved = 4
V2: AI handled it
Expired = 5
Pinned = 6
Implementations
Sourceimpl FeedItemResolution
impl FeedItemResolution
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of FeedItemResolution.
Sourcepub fn from_i32(value: i32) -> Option<FeedItemResolution>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<FeedItemResolution>
Use the TryFrom<i32> implementation instead
Converts an i32 to a FeedItemResolution, or None if value is not a valid variant.
Sourceimpl FeedItemResolution
impl FeedItemResolution
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.