#[repr(i32)]pub enum FeedItemVerificationStatus {
Unspecified = 0,
Verified = 1,
NotVerified = 2,
}Variants
Unspecified = 0
No verification result was computed or the producer could not determine it.
Verified = 1
Verification explicitly reported passing tests with no failures.
NotVerified = 2
Verification explicitly reported a non-passing result or test failures.
Implementations
Sourceimpl FeedItemVerificationStatus
impl FeedItemVerificationStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of FeedItemVerificationStatus.
Sourcepub fn from_i32(value: i32) -> Option<FeedItemVerificationStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<FeedItemVerificationStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a FeedItemVerificationStatus, or None if value is not a valid variant.
Sourceimpl FeedItemVerificationStatus
impl FeedItemVerificationStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.