#[repr(i32)]pub enum HandleKind {
Unspecified = 0,
Native = 1,
Github = 2,
Gitlab = 3,
}Expand description
Shared handle-provider kind from the identity handle registry.
Variants
Implementations
Sourceimpl HandleKind
impl HandleKind
Sourceimpl HandleKind
impl HandleKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.