#[repr(i32)]pub enum HostedObjectType {
Unspecified = 0,
Blob = 1,
Tree = 2,
State = 3,
Action = 4,
Redaction = 5,
StateVisibility = 6,
StateAttachment = 7,
}Expand description
Hosted object discriminants from the native object-store model.
Variants
Unspecified = 0
Blob = 1
Tree = 2
State = 3
Action = 4
Redaction = 5
StateVisibility = 6
StateAttachment = 7
Implementations
Sourceimpl HostedObjectType
impl HostedObjectType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of HostedObjectType.
Sourcepub fn from_i32(value: i32) -> Option<HostedObjectType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<HostedObjectType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a HostedObjectType, or None if value is not a valid variant.
Sourceimpl HostedObjectType
impl HostedObjectType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.