#[repr(i32)]pub enum HostedRole {
Unspecified = 0,
Reader = 1,
Developer = 2,
Maintainer = 3,
Admin = 4,
Owner = 5,
}Expand description
Five-level role grants on hosted namespaces and repositories. Used
wherever a role appears on the wire — HostedGrant.role,
Invitation.role, ApprovalGroupMember.required_role,
ThreadPolicy.required_role, etc.
Variants
Implementations
Sourceimpl HostedRole
impl HostedRole
Sourceimpl HostedRole
impl HostedRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.