#[repr(i32)]pub enum ImportErrorCode {
ImportErrorUnspecified = 0,
ImportErrorInvalidSource = 1,
ImportErrorSourceNotAllowed = 2,
ImportErrorAuthFailed = 3,
ImportErrorNotFound = 4,
ImportErrorTooLarge = 5,
ImportErrorTimedOut = 6,
ImportErrorInternal = 7,
}Expand description
Stable import failure codes from the hosted import operation model.
Variants
ImportErrorUnspecified = 0
ImportErrorInvalidSource = 1
ImportErrorSourceNotAllowed = 2
ImportErrorAuthFailed = 3
ImportErrorNotFound = 4
ImportErrorTooLarge = 5
ImportErrorTimedOut = 6
ImportErrorInternal = 7
Implementations
Sourceimpl ImportErrorCode
impl ImportErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.