#[repr(i32)]pub enum InteractionKind {
Unspecified = 0,
ViewedRepo = 1,
OpenedReview = 2,
CompletedReview = 3,
DismissedItem = 4,
ExpandedSession = 5,
ViewedDiff = 6,
Searched = 7,
}Variants
Unspecified = 0
ViewedRepo = 1
OpenedReview = 2
CompletedReview = 3
DismissedItem = 4
ExpandedSession = 5
ViewedDiff = 6
Searched = 7
V2+: requires stream search feature
Implementations
Sourceimpl InteractionKind
impl InteractionKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.