#[repr(i32)]pub enum LandStackOutcome {
Unspecified = 0,
Committed = 1,
RolledBack = 2,
}Variants
Unspecified = 0
Committed = 1
Every requested member was durably landed in one atomic commit.
RolledBack = 2
No requested member was durably landed. This includes a gate abort and a rollback after an apply failure.
Implementations
Sourceimpl LandStackOutcome
impl LandStackOutcome
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of LandStackOutcome.
Sourcepub fn from_i32(value: i32) -> Option<LandStackOutcome>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<LandStackOutcome>
Use the TryFrom<i32> implementation instead
Converts an i32 to a LandStackOutcome, or None if value is not a valid variant.
Sourceimpl LandStackOutcome
impl LandStackOutcome
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.