#[repr(i32)]pub enum MatchKind {
Unspecified = 0,
Exact = 1,
Prefix = 2,
Fuzzy = 3,
Fulltext = 4,
Semantic = 5,
HashExact = 6,
HashPrefix = 7,
}Expand description
How a hit was produced. Used by MatchProvenance (#976).
Variants
Unspecified = 0
Exact = 1
Prefix = 2
Fuzzy = 3
Fulltext = 4
Semantic = 5
HashExact = 6
HashPrefix = 7
Implementations
Sourceimpl MatchKind
impl MatchKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.