#[repr(i32)]pub enum NamespaceKind {
Unspecified = 0,
User = 1,
Org = 2,
Team = 3,
}Expand description
Namespace kinds in the hosted control plane. USER namespaces are
per-account and auto-created at first sign-in; ORG and TEAM are
explicit organisational containers.
Variants
Implementations
Sourceimpl NamespaceKind
impl NamespaceKind
Sourceimpl NamespaceKind
impl NamespaceKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.