#[repr(i32)]pub enum NotificationChannel {
Unspecified = 0,
InApp = 1,
Email = 2,
WebPush = 3,
}Expand description
Delivery channel for a notification. IN_APP is the always-available channel; EMAIL and WEB_PUSH require the recipient to have registered a destination.
Variants
Implementations
Sourceimpl NotificationChannel
impl NotificationChannel
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of NotificationChannel.
Sourcepub fn from_i32(value: i32) -> Option<NotificationChannel>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<NotificationChannel>
Use the TryFrom<i32> implementation instead
Converts an i32 to a NotificationChannel, or None if value is not a valid variant.
Sourceimpl NotificationChannel
impl NotificationChannel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.