#[repr(i32)]pub enum NotificationDeliveryStatus {
Unspecified = 0,
Pending = 1,
Delivered = 2,
Failed = 3,
Suppressed = 4,
}Expand description
Per-channel delivery outcome for one Notification.
Variants
Unspecified = 0
Pending = 1
Delivered = 2
Failed = 3
Suppressed = 4
routing/preferences suppressed the channel
Implementations
Sourceimpl NotificationDeliveryStatus
impl NotificationDeliveryStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of NotificationDeliveryStatus.
Sourcepub fn from_i32(value: i32) -> Option<NotificationDeliveryStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<NotificationDeliveryStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a NotificationDeliveryStatus, or None if value is not a valid variant.
Sourceimpl NotificationDeliveryStatus
impl NotificationDeliveryStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.