#[repr(i32)]pub enum RecoveryGuardianKind {
Unspecified = 0,
Paper = 1,
Social = 2,
Weft = 3,
}Expand description
Recovery-key provenance is part of the signed policy. A verifier can distinguish paper, social, and Weft guardians when counting signatures.
Variants
Implementations
Sourceimpl RecoveryGuardianKind
impl RecoveryGuardianKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of RecoveryGuardianKind.
Sourcepub fn from_i32(value: i32) -> Option<RecoveryGuardianKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<RecoveryGuardianKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a RecoveryGuardianKind, or None if value is not a valid variant.
Sourceimpl RecoveryGuardianKind
impl RecoveryGuardianKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.