#[repr(i32)]pub enum RecoveryMethodKind {
Unspecified = 0,
TimeLockedWebauthn = 1,
Social = 2,
PaperCode = 3,
}Expand description
Canonical recovery-method kinds. Mirrors the recovery_methods.kind
column. RECOVERY_METHOD_KIND_UNSPECIFIED is rejected by the server.
Variants
Unspecified = 0
TimeLockedWebauthn = 1
Time-locked WebAuthn recovery credential (weft#183).
Social = 2
Social guardians with an M-of-N threshold (weft#185).
PaperCode = 3
Argon2id-hashed paper-code mnemonic (weft#186).
Implementations
Sourceimpl RecoveryMethodKind
impl RecoveryMethodKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of RecoveryMethodKind.
Sourcepub fn from_i32(value: i32) -> Option<RecoveryMethodKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<RecoveryMethodKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a RecoveryMethodKind, or None if value is not a valid variant.
Sourceimpl RecoveryMethodKind
impl RecoveryMethodKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.