#[repr(i32)]pub enum ReferenceKind {
Unspecified = 0,
User = 1,
Agent = 2,
Spool = 3,
Thread = 4,
State = 5,
File = 6,
Line = 7,
Symbol = 8,
}Expand description
Kind of entity a DiscussionReference names.
Snapshot-relative kinds (FILE, LINE, SYMBOL) may carry at; identity
kinds (USER, AGENT, SPOOL, THREAD, STATE) must not.
Variants
Implementations
Sourceimpl ReferenceKind
impl ReferenceKind
Sourceimpl ReferenceKind
impl ReferenceKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.