#[repr(i32)]pub enum ReportFlushState {
Unspecified = 0,
PendingLocal = 1,
QueuedLocal = 2,
Flushed = 3,
}Expand description
Report delivery state emitted by the Heddle actor registry.
Variants
Implementations
Sourceimpl ReportFlushState
impl ReportFlushState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ReportFlushState.
Sourcepub fn from_i32(value: i32) -> Option<ReportFlushState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ReportFlushState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ReportFlushState, or None if value is not a valid variant.
Sourceimpl ReportFlushState
impl ReportFlushState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.