#[repr(i32)]pub enum ReviewKind {
Unspecified = 0,
Read = 1,
AgentPreview = 2,
AgentCoReview = 3,
}Expand description
Review-signature kinds. READ is a human reviewer; the agent variants
distinguish what an AI signing a state was actually doing — preview
(passive read-through) vs co-review (mutating suggestions).
Variants
Implementations
Sourceimpl ReviewKind
impl ReviewKind
Sourceimpl ReviewKind
impl ReviewKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.