#[repr(i32)]pub enum RootStatus {
Unspecified = 0,
Rooted = 1,
Rootless = 2,
UnclaimedAgent = 3,
}Expand description
Owner-root claim status for a subject (api#131).
Variants
Unspecified = 0
Rooted = 1
The subject holds a claimed owner root.
Rootless = 2
The subject has no owner root.
UnclaimedAgent = 3
The subject is an agent account whose owner root is not yet claimed.
Implementations
Sourceimpl RootStatus
impl RootStatus
Sourceimpl RootStatus
impl RootStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.