#[repr(i32)]pub enum SearchEntityKind {
Unspecified = 0,
User = 1,
Repo = 2,
Agent = 3,
Thread = 4,
Feed = 5,
}Expand description
Request-side scope filter only. The response has no entity-kind enum: the
SearchHit oneof tag IS the entity kind (no illegal kind/payload mismatch).
Variants
Unspecified = 0
User = 1
Repo = 2
Agent = 3
Thread = 4
Feed = 5
6+ reserved for Tier 2: CONTENT, MESSAGE, STATE, SYMBOL.
Implementations
Sourceimpl SearchEntityKind
impl SearchEntityKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SearchEntityKind.
Sourcepub fn from_i32(value: i32) -> Option<SearchEntityKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SearchEntityKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SearchEntityKind, or None if value is not a valid variant.
Sourceimpl SearchEntityKind
impl SearchEntityKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.