#[repr(i32)]pub enum SignatureActorKind {
Unspecified = 0,
Human = 1,
Agent = 2,
}Expand description
The server-derived identity class of a verified signer.
Variants
Implementations
Sourceimpl SignatureActorKind
impl SignatureActorKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SignatureActorKind.
Sourcepub fn from_i32(value: i32) -> Option<SignatureActorKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SignatureActorKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SignatureActorKind, or None if value is not a valid variant.
Sourceimpl SignatureActorKind
impl SignatureActorKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.