#[repr(i32)]pub enum SignupEmailChallengeAcceptanceStatus {
Unspecified = 0,
Accepted = 1,
}Expand description
Generic acknowledgement for a syntactically valid challenge request. There is deliberately no rejected/no-invite state: challenge acceptance does not disclose whether recipient_email has a usable invite.
Variants
Implementations
Sourceimpl SignupEmailChallengeAcceptanceStatus
impl SignupEmailChallengeAcceptanceStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SignupEmailChallengeAcceptanceStatus.
Sourcepub fn from_i32(value: i32) -> Option<SignupEmailChallengeAcceptanceStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SignupEmailChallengeAcceptanceStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SignupEmailChallengeAcceptanceStatus, or None if value is not a valid variant.
Sourceimpl SignupEmailChallengeAcceptanceStatus
impl SignupEmailChallengeAcceptanceStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.