#[repr(i32)]pub enum StructuredConflictStatus {
Unspecified = 0,
Open = 1,
AutoResolved = 2,
Resolved = 3,
}Expand description
Lifecycle of one conflict region within a state attachment. Maps to tapestry’s open | auto_resolved | resolved vocabulary.
Variants
Unspecified = 0
Open = 1
Still open — no resolution fields populated.
AutoResolved = 2
Closed by automatic resolution (ConflictResolutionMode.AUTO).
Resolved = 3
Closed by an explicit choice or edit (ours / theirs / edit).
Implementations
Sourceimpl StructuredConflictStatus
impl StructuredConflictStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of StructuredConflictStatus.
Sourcepub fn from_i32(value: i32) -> Option<StructuredConflictStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<StructuredConflictStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a StructuredConflictStatus, or None if value is not a valid variant.
Sourceimpl StructuredConflictStatus
impl StructuredConflictStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.