#[repr(i32)]pub enum SymbolKind {
Unspecified = 0,
Function = 1,
Type = 2,
Enum = 3,
Trait = 4,
Class = 5,
Interface = 6,
TypeAlias = 7,
Const = 8,
Module = 9,
Other = 10,
}Expand description
Symbol kinds emitted by the repository semantic index (api#32).
Variants
Unspecified = 0
Function = 1
Type = 2
Enum = 3
Trait = 4
Class = 5
Interface = 6
TypeAlias = 7
Const = 8
Module = 9
Other = 10
Implementations
Sourceimpl SymbolKind
impl SymbolKind
Sourceimpl SymbolKind
impl SymbolKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.