#[repr(i32)]pub enum ThreadFreshness {
Unspecified = 0,
Current = 1,
Stale = 2,
Unknown = 3,
NotChecked = 4,
}Expand description
Thread freshness vocabulary from heddle/repo/src/thread_model.rs.
Variants
Implementations
Sourceimpl ThreadFreshness
impl ThreadFreshness
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.