#[repr(i32)]pub enum ThreadMode {
Unspecified = 0,
Materialized = 1,
Virtualized = 2,
Solid = 3,
}Expand description
Thread materialization mode from heddle/repo/src/thread_model.rs.
Variants
Implementations
Sourceimpl ThreadMode
impl ThreadMode
Sourceimpl ThreadMode
impl ThreadMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.