#[repr(i32)]pub enum ThreadOrder {
Unspecified = 0,
LastActivityDesc = 1,
NameAsc = 2,
}Variants
Unspecified = 0
LastActivityDesc = 1
Most-recently-active first, ordered by ThreadSummary.last_activity_at.
NameAsc = 2
Implementations
Sourceimpl ThreadOrder
impl ThreadOrder
Sourceimpl ThreadOrder
impl ThreadOrder
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.