pub enum Context {
Retry(RetryAdvice),
Conflict(ConflictDetail),
Cursor(CursorFailure),
Capability(CapabilityRequirement),
Policy(PolicyDenial),
HumanVerification(HumanVerificationChallenge),
AmbiguousChangeId(AmbiguousChangeIdDetail),
Signup(SignupFailure),
}Variants
Retry(RetryAdvice)
Conflict(ConflictDetail)
Cursor(CursorFailure)
Capability(CapabilityRequirement)
Policy(PolicyDenial)
HumanVerification(HumanVerificationChallenge)
A human-verification challenge the caller must satisfy (carried here now that CallFailure dropped the Any details channel).
AmbiguousChangeId(AmbiguousChangeIdDetail)
Signup(SignupFailure)
Implementations
Sourceimpl Context
impl Context
Sourcepub fn merge(
field: &mut Option<Context>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Context>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.