pub struct Source {
pub domain: i32,
pub status: i32,
pub match_count: u32,
}Fields
domain: i32status: i32match_count: u32Implementations
Sourceimpl Source
impl Source
Sourcepub fn domain(&self) -> SearchEntityKind
pub fn domain(&self) -> SearchEntityKind
Returns the enum value of domain, or the default if the field is set to an invalid enum value.
Sourcepub fn set_domain(&mut self, value: SearchEntityKind)
pub fn set_domain(&mut self, value: SearchEntityKind)
Sets domain to the provided enum value.
Sourcepub fn status(&self) -> SourceStatus
pub fn status(&self) -> SourceStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SourceStatus)
pub fn set_status(&mut self, value: SourceStatus)
Sets status to the provided enum value.