pub struct ResolveIntoAnnotation {
pub kind: i32,
pub content: String,
pub tags: Vec<String>,
}Fields
kind: i32content: StringImplementations
Sourceimpl ResolveIntoAnnotation
impl ResolveIntoAnnotation
Sourcepub fn kind(&self) -> ContextAnnotationKind
pub fn kind(&self) -> ContextAnnotationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ContextAnnotationKind)
pub fn set_kind(&mut self, value: ContextAnnotationKind)
Sets kind to the provided enum value.