pub struct AgentCommandAcknowledgement {
pub command_id: Option<AgentCommandId>,
pub status: i32,
pub content_hash: String,
}Fields
command_id: Option<AgentCommandId>status: i32content_hash: StringImplementations
Sourceimpl AgentCommandAcknowledgement
impl AgentCommandAcknowledgement
Sourcepub fn status(&self) -> AgentCommandStatus
pub fn status(&self) -> AgentCommandStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: AgentCommandStatus)
pub fn set_status(&mut self, value: AgentCommandStatus)
Sets status to the provided enum value.