pub struct AgentCommandAudit {
pub command_id: Option<AgentCommandId>,
pub status: i32,
pub actor_subject: String,
pub content_hash: String,
pub created_at: Option<Timestamp>,
pub completed_at: Option<Timestamp>,
}Fields
command_id: Option<AgentCommandId>status: i32actor_subject: Stringcontent_hash: Stringcreated_at: Option<Timestamp>completed_at: Option<Timestamp>Implementations
Sourceimpl AgentCommandAudit
impl AgentCommandAudit
Sourcepub fn status(&self) -> AgentCommandStatus
pub fn status(&self) -> AgentCommandStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: AgentCommandStatus)
pub fn set_status(&mut self, value: AgentCommandStatus)
Sets status to the provided enum value.