pub struct AgentCommandDelivery {
pub command_id: Option<AgentCommandId>,
pub kind: i32,
pub encrypted_steering_text: Vec<u8>,
pub expires_at: Option<Timestamp>,
}Fields
command_id: Option<AgentCommandId>kind: i32encrypted_steering_text: Vec<u8>expires_at: Option<Timestamp>Implementations
Sourceimpl AgentCommandDelivery
impl AgentCommandDelivery
Sourcepub fn kind(&self) -> AgentControlKind
pub fn kind(&self) -> AgentControlKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: AgentControlKind)
pub fn set_kind(&mut self, value: AgentControlKind)
Sets kind to the provided enum value.