pub struct AgentRun {
pub run_id: Option<AgentRunId>,
pub repository: Option<RepositoryRef>,
pub initiating_human_subject: String,
pub service_account_subject: String,
pub provider: String,
pub model: String,
pub harness: String,
pub status: i32,
pub visibility: i32,
pub started_at: Option<Timestamp>,
pub finished_at: Option<Timestamp>,
}Fields
run_id: Option<AgentRunId>repository: Option<RepositoryRef>initiating_human_subject: Stringservice_account_subject: Stringprovider: Stringmodel: Stringharness: Stringstatus: i32visibility: i32started_at: Option<Timestamp>finished_at: Option<Timestamp>Implementations
Sourceimpl AgentRun
impl AgentRun
Sourcepub fn status(&self) -> AgentRunStatus
pub fn status(&self) -> AgentRunStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: AgentRunStatus)
pub fn set_status(&mut self, value: AgentRunStatus)
Sets status to the provided enum value.
Sourcepub fn visibility(&self) -> AgentVisibility
pub fn visibility(&self) -> AgentVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: AgentVisibility)
pub fn set_visibility(&mut self, value: AgentVisibility)
Sets visibility to the provided enum value.