pub struct AgentRunUpdate {
pub run_id: Option<AgentRunId>,
pub status: i32,
pub progress_summary: String,
pub usage: Option<UsageUpdate>,
pub observed_at: Option<Timestamp>,
}Fields
run_id: Option<AgentRunId>status: i32progress_summary: Stringusage: Option<UsageUpdate>observed_at: Option<Timestamp>Implementations
Sourceimpl AgentRunUpdate
impl AgentRunUpdate
Sourcepub fn status(&self) -> AgentRunStatus
pub fn status(&self) -> AgentRunStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: AgentRunStatus)
pub fn set_status(&mut self, value: AgentRunStatus)
Sets status to the provided enum value.