pub struct AuthChallengeResponse {
pub challenge_id: String,
pub challenge: String,
pub expires_at: Option<Timestamp>,
pub username: String,
pub rp_id: String,
pub rp_name: String,
pub user_id: String,
pub display_name: String,
pub allow_credential_ids: Vec<String>,
pub attestation: String,
pub user_verification: String,
}Fields
challenge_id: Stringchallenge: Stringexpires_at: Option<Timestamp>username: Stringrp_id: Stringrp_name: Stringuser_id: Stringdisplay_name: Stringallow_credential_ids: Vec<String>attestation: Stringuser_verification: StringTrait Implementations
Sourceimpl Clone for AuthChallengeResponse
impl Clone for AuthChallengeResponse
Sourcefn clone(&self) -> AuthChallengeResponse
fn clone(&self) -> AuthChallengeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthChallengeResponse
impl Debug for AuthChallengeResponse
Sourceimpl Default for AuthChallengeResponse
impl Default for AuthChallengeResponse
impl Eq for AuthChallengeResponse
Sourceimpl Hash for AuthChallengeResponse
impl Hash for AuthChallengeResponse
Sourceimpl Message for AuthChallengeResponse
impl Message for AuthChallengeResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AuthChallengeResponse
impl PartialEq for AuthChallengeResponse
impl StructuralPartialEq for AuthChallengeResponse