pub struct AuthorizationRequestTarget {
pub path: String,
pub role: i32,
}Fields
path: StringA protobuf field path in the request, using proto field names separated by dots.
role: i32The role required for the resource selected by path.
Implementations
Sourceimpl AuthorizationRequestTarget
impl AuthorizationRequestTarget
Sourcepub fn role(&self) -> AuthorizationRole
pub fn role(&self) -> AuthorizationRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: AuthorizationRole)
pub fn set_role(&mut self, value: AuthorizationRole)
Sets role to the provided enum value.