pub struct BeginRecoveryRequest {
pub username: String,
pub kind: i32,
pub client_operation_id: String,
}Expand description
Start a recovery attempt for a username. weft#183 8-3.
Fields
username: Stringkind: i32Which declared method the client intends to prove. Lets the server scope
the attempt (and the returned window) to the right recovery_methods
row. Server rejects a kind the user has not declared.
client_operation_id: StringImplementations
Sourceimpl BeginRecoveryRequest
impl BeginRecoveryRequest
Sourcepub fn kind(&self) -> RecoveryMethodKind
pub fn kind(&self) -> RecoveryMethodKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: RecoveryMethodKind)
pub fn set_kind(&mut self, value: RecoveryMethodKind)
Sets kind to the provided enum value.