pub struct CallFailure {
pub code: i32,
pub message: String,
pub error: Option<ErrorDetail>,
}Fields
code: i32message: Stringerror: Option<ErrorDetail>Implementations
Sourceimpl CallFailure
impl CallFailure
Sourcepub fn code(&self) -> CallFailureCode
pub fn code(&self) -> CallFailureCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: CallFailureCode)
pub fn set_code(&mut self, value: CallFailureCode)
Sets code to the provided enum value.