pub struct CapabilityPrincipal {
pub kind: i32,
pub principal_id: Vec<u8>,
pub key: Option<AuthorizationVerificationKey>,
}Fields
kind: i32principal_id: Vec<u8>Signed audit identity, not an ownership anchor.
key: Option<AuthorizationVerificationKey>Absent only for ANY_ANONYMOUS.
Implementations
Sourceimpl CapabilityPrincipal
impl CapabilityPrincipal
Sourcepub fn kind(&self) -> CapabilityPrincipalKind
pub fn kind(&self) -> CapabilityPrincipalKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CapabilityPrincipalKind)
pub fn set_kind(&mut self, value: CapabilityPrincipalKind)
Sets kind to the provided enum value.