pub struct ChannelRule {
pub kind: i32,
pub channel: i32,
pub actor_origin: i32,
pub routing: i32,
}Expand description
One cell of the preference matrix: for a (kind, channel, actor_origin) key,
route matching notifications per routing. A rule with the UNSPECIFIED kind
or channel acts as a wildcard default for that axis.
Fields
kind: i32channel: i32actor_origin: i32routing: i32Implementations
Sourceimpl ChannelRule
impl ChannelRule
Sourcepub fn kind(&self) -> NotificationKind
pub fn kind(&self) -> NotificationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: NotificationKind)
pub fn set_kind(&mut self, value: NotificationKind)
Sets kind to the provided enum value.
Sourcepub fn channel(&self) -> NotificationChannel
pub fn channel(&self) -> NotificationChannel
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: NotificationChannel)
pub fn set_channel(&mut self, value: NotificationChannel)
Sets channel to the provided enum value.
Sourcepub fn actor_origin(&self) -> ActorOrigin
pub fn actor_origin(&self) -> ActorOrigin
Returns the enum value of actor_origin, or the default if the field is set to an invalid enum value.
Sourcepub fn set_actor_origin(&mut self, value: ActorOrigin)
pub fn set_actor_origin(&mut self, value: ActorOrigin)
Sets actor_origin to the provided enum value.
Sourcepub fn routing(&self) -> NotificationRouting
pub fn routing(&self) -> NotificationRouting
Returns the enum value of routing, or the default if the field is set to an invalid enum value.
Sourcepub fn set_routing(&mut self, value: NotificationRouting)
pub fn set_routing(&mut self, value: NotificationRouting)
Sets routing to the provided enum value.