pub struct ChildEdge {
pub parent_spool_id: String,
pub child_spool_id: String,
pub mount_name: String,
pub anchored_state_id: Option<StateId>,
pub child_head: Option<StateId>,
pub status: i32,
}Expand description
One resolved child edge. Mirrors weft children::ChildEdge.
Fields
parent_spool_id: Stringchild_spool_id: Stringmount_name: Stringanchored_state_id: Option<StateId>The child content state-id this edge is currently anchored to (16-byte ChangeId).
child_head: Option<StateId>The child’s latest content-facet head, if any (absent = child has no content head yet).
status: i32Moving-anchored-ff status of the anchor vs the child head.
Implementations
Sourceimpl ChildEdge
impl ChildEdge
Sourcepub fn status(&self) -> ChildEdgeStatus
pub fn status(&self) -> ChildEdgeStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ChildEdgeStatus)
pub fn set_status(&mut self, value: ChildEdgeStatus)
Sets status to the provided enum value.