pub struct ConflictResolverAttribution {
pub kind: i32,
pub principal: Option<ConflictResolverPrincipal>,
pub agent: Option<ConflictResolverAgent>,
}Expand description
Who/what resolved a conflict. Mirrors heddle ResolverAttributionReport.
Populated only when StructuredConflict.status is AUTO_RESOLVED or RESOLVED.
Fields
kind: i32principal: Option<ConflictResolverPrincipal>agent: Option<ConflictResolverAgent>Set when kind == AGENT; omit for human resolutions.
Implementations
Sourceimpl ConflictResolverAttribution
impl ConflictResolverAttribution
Sourcepub fn kind(&self) -> ConflictResolverKind
pub fn kind(&self) -> ConflictResolverKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ConflictResolverKind)
pub fn set_kind(&mut self, value: ConflictResolverKind)
Sets kind to the provided enum value.