pub struct ContextAnnotation {Show 14 fields
pub id: String,
pub scope: Option<AnnotationScope>,
pub content: String,
pub tags: Vec<String>,
pub attribution: String,
pub created_at: Option<Timestamp>,
pub source_hash: Option<Vec<u8>>,
pub created_at_state: Option<StateId>,
pub staleness: i32,
pub status: i32,
pub kind: i32,
pub revision_count: u32,
pub supersedes_annotation_id: Option<String>,
pub supersedes_rewrite_pct: Option<u32>,
}Fields
id: Stringscope: Option<AnnotationScope>content: Stringattribution: Stringcreated_at: Option<Timestamp>source_hash: Option<Vec<u8>>created_at_state: Option<StateId>staleness: i32status: i32kind: i32revision_count: u32supersedes_annotation_id: Option<String>supersedes_rewrite_pct: Option<u32>Implementations
Sourceimpl ContextAnnotation
impl ContextAnnotation
Sourcepub fn source_hash(&self) -> &[u8] ⓘ
pub fn source_hash(&self) -> &[u8] ⓘ
Returns the value of source_hash, or the default value if source_hash is unset.
Sourcepub fn staleness(&self) -> StalenessStatus
pub fn staleness(&self) -> StalenessStatus
Returns the enum value of staleness, or the default if the field is set to an invalid enum value.
Sourcepub fn set_staleness(&mut self, value: StalenessStatus)
pub fn set_staleness(&mut self, value: StalenessStatus)
Sets staleness to the provided enum value.
Sourcepub fn status(&self) -> ContextAnnotationStatus
pub fn status(&self) -> ContextAnnotationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ContextAnnotationStatus)
pub fn set_status(&mut self, value: ContextAnnotationStatus)
Sets status to the provided enum value.
Sourcepub fn kind(&self) -> ContextAnnotationKind
pub fn kind(&self) -> ContextAnnotationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ContextAnnotationKind)
pub fn set_kind(&mut self, value: ContextAnnotationKind)
Sets kind to the provided enum value.
Sourcepub fn supersedes_annotation_id(&self) -> &str
pub fn supersedes_annotation_id(&self) -> &str
Returns the value of supersedes_annotation_id, or the default value if supersedes_annotation_id is unset.
Sourcepub fn supersedes_rewrite_pct(&self) -> u32
pub fn supersedes_rewrite_pct(&self) -> u32
Returns the value of supersedes_rewrite_pct, or the default value if supersedes_rewrite_pct is unset.