pub struct ContextRevision {
pub revision_id: String,
pub kind: i32,
pub content: String,
pub tags: Vec<String>,
pub attribution: String,
pub created_at: Option<Timestamp>,
pub source_hash: Option<Vec<u8>>,
pub created_at_state: Option<StateId>,
}Fields
revision_id: Stringkind: i32content: Stringattribution: Stringcreated_at: Option<Timestamp>source_hash: Option<Vec<u8>>created_at_state: Option<StateId>Implementations
Sourceimpl ContextRevision
impl ContextRevision
Sourcepub fn kind(&self) -> ContextAnnotationKind
pub fn kind(&self) -> ContextAnnotationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ContextAnnotationKind)
pub fn set_kind(&mut self, value: ContextAnnotationKind)
Sets kind to the provided enum value.
Sourcepub fn source_hash(&self) -> &[u8] ⓘ
pub fn source_hash(&self) -> &[u8] ⓘ
Returns the value of source_hash, or the default value if source_hash is unset.