pub struct ContextSuggestion {
pub path: String,
pub score: u32,
pub tier: i32,
pub reasons: Vec<String>,
pub recent_changes: u32,
pub distinct_states: u32,
pub distinct_agents: u32,
pub has_context: bool,
pub stale_annotations: u32,
}Fields
path: Stringscore: u32tier: i32reasons: Vec<String>recent_changes: u32distinct_states: u32distinct_agents: u32has_context: boolstale_annotations: u32Implementations
Sourceimpl ContextSuggestion
impl ContextSuggestion
Sourcepub fn tier(&self) -> ContextSuggestionTier
pub fn tier(&self) -> ContextSuggestionTier
Returns the enum value of tier, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tier(&mut self, value: ContextSuggestionTier)
pub fn set_tier(&mut self, value: ContextSuggestionTier)
Sets tier to the provided enum value.