pub struct ControlAgentRequest {
pub run_id: Option<AgentRunId>,
pub control: i32,
pub encrypted_steering_text: Vec<u8>,
pub client_operation_id: String,
}Fields
run_id: Option<AgentRunId>control: i32encrypted_steering_text: Vec<u8>client_operation_id: StringImplementations
Sourceimpl ControlAgentRequest
impl ControlAgentRequest
Sourcepub fn control(&self) -> AgentControlKind
pub fn control(&self) -> AgentControlKind
Returns the enum value of control, or the default if the field is set to an invalid enum value.
Sourcepub fn set_control(&mut self, value: AgentControlKind)
pub fn set_control(&mut self, value: AgentControlKind)
Sets control to the provided enum value.