pub struct CreateGrantRequest {
pub subject: String,
pub role: i32,
pub target: Option<GrantTargetRef>,
pub client_operation_id: String,
}Fields
subject: Stringrole: i32target: Option<GrantTargetRef>client_operation_id: StringImplementations
Sourceimpl CreateGrantRequest
impl CreateGrantRequest
Sourcepub fn role(&self) -> HostedRole
pub fn role(&self) -> HostedRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: HostedRole)
pub fn set_role(&mut self, value: HostedRole)
Sets role to the provided enum value.