pub struct CreateSignupInviteRequest {
pub recipient_email: Option<String>,
pub client_operation_id: String,
}Fields
recipient_email: Option<String>Optional address to bind to the new invite. When present, Weft canonicalizes and persists it using the same binding rules as BindSignupInviteEmail.
client_operation_id: StringIdempotency key scoped to the authenticated member and this RPC. Reuse with a different recipient_email must fail without spending allowance.
Implementations
Sourceimpl CreateSignupInviteRequest
impl CreateSignupInviteRequest
Sourcepub fn recipient_email(&self) -> &str
pub fn recipient_email(&self) -> &str
Returns the value of recipient_email, or the default value if recipient_email is unset.