pub struct CredentialInfo {
pub credential_id: String,
pub subject: String,
pub kind: i32,
pub scope: String,
pub expires_at: Option<Timestamp>,
pub revoked: bool,
pub device_id: Option<String>,
pub provider: Option<String>,
pub model: Option<String>,
pub created_at: Option<Timestamp>,
pub last_used_at: Option<Timestamp>,
}Fields
credential_id: Stringsubject: Stringkind: i32scope: Stringexpires_at: Option<Timestamp>Epoch seconds. 0 = never expires.
revoked: booldevice_id: Option<String>provider: Option<String>model: Option<String>created_at: Option<Timestamp>Epoch seconds, always populated.
last_used_at: Option<Timestamp>Epoch seconds. 0 = never used. Touched on every successful Biscuit validation.
Implementations
Sourceimpl CredentialInfo
impl CredentialInfo
Sourcepub fn kind(&self) -> CredentialKind
pub fn kind(&self) -> CredentialKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CredentialKind)
pub fn set_kind(&mut self, value: CredentialKind)
Sets kind to the provided enum value.
Sourcepub fn device_id(&self) -> &str
pub fn device_id(&self) -> &str
Returns the value of device_id, or the default value if device_id is unset.