pub struct DecideAgentPermissionRequest {
pub run_id: Option<AgentRunId>,
pub permission_id: Option<PermissionId>,
pub decision: i32,
pub client_operation_id: String,
}Fields
run_id: Option<AgentRunId>permission_id: Option<PermissionId>decision: i32client_operation_id: StringImplementations
Sourceimpl DecideAgentPermissionRequest
impl DecideAgentPermissionRequest
Sourcepub fn decision(&self) -> PermissionDecisionKind
pub fn decision(&self) -> PermissionDecisionKind
Returns the enum value of decision, or the default if the field is set to an invalid enum value.
Sourcepub fn set_decision(&mut self, value: PermissionDecisionKind)
pub fn set_decision(&mut self, value: PermissionDecisionKind)
Sets decision to the provided enum value.