pub struct DeclareRecoveryMethodResponse {
pub method_id: String,
pub kind: i32,
pub declared_at: Option<Timestamp>,
pub bootstrap_promoted: bool,
pub promoted_token: String,
}Expand description
Shared response for the declaration RPC. bootstrap_promoted is true when
this was the user’s first declared method and the server promoted the
caller’s bootstrap-scope Biscuit to full scope (weft#120 Q2). When a
promotion occurs, promoted_token carries the newly-minted full-scope
Biscuit; empty otherwise.
Fields
method_id: StringStable id of the persisted recovery_methods row.
kind: i32declared_at: Option<Timestamp>bootstrap_promoted: boolpromoted_token: StringImplementations
Sourceimpl DeclareRecoveryMethodResponse
impl DeclareRecoveryMethodResponse
Sourcepub fn kind(&self) -> RecoveryMethodKind
pub fn kind(&self) -> RecoveryMethodKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: RecoveryMethodKind)
pub fn set_kind(&mut self, value: RecoveryMethodKind)
Sets kind to the provided enum value.