pub struct Discussion {
pub id: String,
pub anchor: Option<PathSymbolRef>,
pub opened_against_state: Option<StateId>,
pub opened_at: Option<Timestamp>,
pub thread_ref: String,
pub turns: Vec<DiscussionTurn>,
pub resolution: Option<DiscussionResolution>,
pub body_changed_since_open: bool,
pub orphaned: bool,
pub visibility: String,
pub resolved_annotation_id: String,
}Fields
id: Stringanchor: Option<PathSymbolRef>opened_against_state: Option<StateId>opened_at: Option<Timestamp>thread_ref: Stringturns: Vec<DiscussionTurn>resolution: Option<DiscussionResolution>body_changed_since_open: boolorphaned: boolvisibility: Stringresolved_annotation_id: StringTrait Implementations
Sourceimpl Clone for Discussion
impl Clone for Discussion
Sourcefn clone(&self) -> Discussion
fn clone(&self) -> Discussion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Discussion
impl Debug for Discussion
Sourceimpl Default for Discussion
impl Default for Discussion
Sourceimpl Message for Discussion
impl Message for Discussion
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for Discussion
impl PartialEq for Discussion
impl StructuralPartialEq for Discussion