pub struct DiscussionDigest {
pub id: String,
pub anchor: Option<PathSymbolRef>,
pub opened_against_state: Option<StateId>,
pub opened_at: Option<Timestamp>,
pub turn_count: u32,
pub orphaned: bool,
pub resolved: bool,
pub visibility: String,
pub thread_ref: String,
pub thread_id: String,
}Expand description
Lightweight per-discussion projection for overview cards. Omits turn bodies; clients that need the full thread call GetDiscussion / ListByState.
Fields
id: Stringanchor: Option<PathSymbolRef>opened_against_state: Option<StateId>opened_at: Option<Timestamp>turn_count: u32orphaned: boolresolved: boolvisibility: Stringthread_ref: Stringthread_id: StringTrait Implementations
Sourceimpl Clone for DiscussionDigest
impl Clone for DiscussionDigest
Sourcefn clone(&self) -> DiscussionDigest
fn clone(&self) -> DiscussionDigest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscussionDigest
impl Debug for DiscussionDigest
Sourceimpl Default for DiscussionDigest
impl Default for DiscussionDigest
impl Eq for DiscussionDigest
Sourceimpl Hash for DiscussionDigest
impl Hash for DiscussionDigest
Sourceimpl Message for DiscussionDigest
impl Message for DiscussionDigest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DiscussionDigest
impl PartialEq for DiscussionDigest
impl StructuralPartialEq for DiscussionDigest