pub struct EndpointDescriptor {
pub version: u32,
pub endpoint_id: String,
pub relay_urls: Vec<String>,
pub supported_alpns: Vec<Vec<u8>>,
pub direct_addresses: Vec<String>,
pub issued_at_unix_millis: i64,
pub expires_at_unix_millis: i64,
pub rotation: Option<DescriptorKeyRotation>,
}Expand description
HTTPS bootstrap document for the terminating Weft Iroh application endpoint. The descriptor is signed by the key named by SignedEndpointDescriptor.key_id.
Fields
version: u32endpoint_id: Stringrelay_urls: Vec<String>supported_alpns: Vec<Vec<u8>>direct_addresses: Vec<String>issued_at_unix_millis: i64expires_at_unix_millis: i64rotation: Option<DescriptorKeyRotation>Trait Implementations
Sourceimpl Clone for EndpointDescriptor
impl Clone for EndpointDescriptor
Sourcefn clone(&self) -> EndpointDescriptor
fn clone(&self) -> EndpointDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointDescriptor
impl Debug for EndpointDescriptor
Sourceimpl Default for EndpointDescriptor
impl Default for EndpointDescriptor
impl Eq for EndpointDescriptor
Sourceimpl Hash for EndpointDescriptor
impl Hash for EndpointDescriptor
Sourceimpl Message for EndpointDescriptor
impl Message for EndpointDescriptor
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EndpointDescriptor
impl PartialEq for EndpointDescriptor
impl StructuralPartialEq for EndpointDescriptor