pub struct Entitlement {
pub plan: i32,
pub status: i32,
pub current_period_end: Option<Timestamp>,
}Expand description
The account-level entitlement applied for a subject.
Fields
plan: i32status: i32current_period_end: Option<Timestamp>Implementations
Sourceimpl Entitlement
impl Entitlement
Sourcepub fn plan(&self) -> Plan
pub fn plan(&self) -> Plan
Returns the enum value of plan, or the default if the field is set to an invalid enum value.
Sourcepub fn status(&self) -> SubscriptionStatus
pub fn status(&self) -> SubscriptionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SubscriptionStatus)
pub fn set_status(&mut self, value: SubscriptionStatus)
Sets status to the provided enum value.