pub struct FeedCaptureSummary {
pub state_id: Option<StateId>,
pub change_id: Option<ChangeId>,
pub thread: String,
pub capture_message: String,
pub author_display: String,
pub captured_at: Option<Timestamp>,
pub additions: u32,
pub deletions: u32,
}Expand description
Metadata and line delta read from one exact capture. capture_message is the
capture’s intent, never a FeedItem headline. author_display is the capture
State’s accountable principal rendered as “Name
Fields
state_id: Option<StateId>change_id: Option<ChangeId>thread: Stringcapture_message: Stringcaptured_at: Option<Timestamp>additions: u32deletions: u32Trait Implementations
Sourceimpl Clone for FeedCaptureSummary
impl Clone for FeedCaptureSummary
Sourcefn clone(&self) -> FeedCaptureSummary
fn clone(&self) -> FeedCaptureSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeedCaptureSummary
impl Debug for FeedCaptureSummary
Sourceimpl Default for FeedCaptureSummary
impl Default for FeedCaptureSummary
impl Eq for FeedCaptureSummary
Sourceimpl Hash for FeedCaptureSummary
impl Hash for FeedCaptureSummary
Sourceimpl Message for FeedCaptureSummary
impl Message for FeedCaptureSummary
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FeedCaptureSummary
impl PartialEq for FeedCaptureSummary
impl StructuralPartialEq for FeedCaptureSummary