pub struct FileChangeSummary {
pub path: String,
pub kind: i32,
}Fields
path: Stringkind: i32Implementations
Sourceimpl FileChangeSummary
impl FileChangeSummary
Sourcepub fn kind(&self) -> FileChangeKind
pub fn kind(&self) -> FileChangeKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: FileChangeKind)
pub fn set_kind(&mut self, value: FileChangeKind)
Sets kind to the provided enum value.