pub struct GetReviewAnalysisStatusResponse {
pub job_id: String,
pub status: i32,
pub phase: i32,
pub current: u32,
pub total: u32,
pub label: String,
pub updated_at: Option<Timestamp>,
pub head_sha: String,
}Fields
job_id: Stringstatus: i32phase: i32current: u32total: u32label: Stringupdated_at: Option<Timestamp>head_sha: StringImplementations
Sourceimpl GetReviewAnalysisStatusResponse
impl GetReviewAnalysisStatusResponse
Sourcepub fn status(&self) -> ReviewJobStatus
pub fn status(&self) -> ReviewJobStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ReviewJobStatus)
pub fn set_status(&mut self, value: ReviewJobStatus)
Sets status to the provided enum value.
Sourcepub fn phase(&self) -> ReviewJobPhase
pub fn phase(&self) -> ReviewJobPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: ReviewJobPhase)
pub fn set_phase(&mut self, value: ReviewJobPhase)
Sets phase to the provided enum value.