pub struct GitObjectId {
pub algorithm: i32,
pub digest: Vec<u8>,
}Fields
algorithm: i32digest: Vec<u8>Implementations
Sourceimpl GitObjectId
impl GitObjectId
Sourcepub fn algorithm(&self) -> GitObjectAlgorithm
pub fn algorithm(&self) -> GitObjectAlgorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: GitObjectAlgorithm)
pub fn set_algorithm(&mut self, value: GitObjectAlgorithm)
Sets algorithm to the provided enum value.
Sourceimpl GitObjectId
impl GitObjectId
Sourcepub fn from_digest(
algorithm: GitObjectAlgorithm,
digest: impl AsRef<[u8]>,
) -> Result<Self, InvalidIdentifierLength>
pub fn from_digest( algorithm: GitObjectAlgorithm, digest: impl AsRef<[u8]>, ) -> Result<Self, InvalidIdentifierLength>
Constructs and validates a Git object identifier for its hash algorithm.