pub struct GitRefUpdateTransfer {
pub name: String,
pub kind: i32,
pub target_oid: Option<GitObjectId>,
pub peeled_oid: Option<GitObjectId>,
pub expected_missing: bool,
pub expected_target_oid: Option<GitObjectId>,
pub checkpoint: Option<GitCheckpointTransfer>,
}Fields
name: Stringkind: i32target_oid: Option<GitObjectId>peeled_oid: Option<GitObjectId>expected_missing: boolexpected_target_oid: Option<GitObjectId>checkpoint: Option<GitCheckpointTransfer>Implementations
Sourceimpl GitRefUpdateTransfer
impl GitRefUpdateTransfer
Sourcepub fn kind(&self) -> GitRefKind
pub fn kind(&self) -> GitRefKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: GitRefKind)
pub fn set_kind(&mut self, value: GitRefKind)
Sets kind to the provided enum value.