pub struct GovernanceSettingMergePolicy {
pub setting_key: String,
pub semantics: i32,
}Fields
setting_key: StringThe canonical protobuf field name in SpoolSettings. Entries are sorted
by UTF-8 bytes in canonical_owner_governance_state_v1. Unknown, missing,
and duplicate keys fail closed.
semantics: i32Implementations
Sourceimpl GovernanceSettingMergePolicy
impl GovernanceSettingMergePolicy
Sourcepub fn semantics(&self) -> GovernanceSettingMergeSemantics
pub fn semantics(&self) -> GovernanceSettingMergeSemantics
Returns the enum value of semantics, or the default if the field is set to an invalid enum value.
Sourcepub fn set_semantics(&mut self, value: GovernanceSettingMergeSemantics)
pub fn set_semantics(&mut self, value: GovernanceSettingMergeSemantics)
Sets semantics to the provided enum value.