pub struct HandlePrincipal {
pub display_name: String,
pub handle: String,
pub resolved: bool,
pub primary_handle: String,
pub kind: String,
pub verified: bool,
pub discriminator: String,
}Expand description
Subject-free handle-directory projection. ResolveHandle requires a valid
bearer, but there is deliberately no subject field: resolving a name MUST NOT
expose an underlying subject. primary_handle is the canonical URL/display
token for the active principal.
Fields
display_name: Stringhandle: Stringresolved: boolprimary_handle: Stringkind: Stringverified: booldiscriminator: StringTrait Implementations
Sourceimpl Clone for HandlePrincipal
impl Clone for HandlePrincipal
Sourcefn clone(&self) -> HandlePrincipal
fn clone(&self) -> HandlePrincipal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HandlePrincipal
impl Debug for HandlePrincipal
Sourceimpl Default for HandlePrincipal
impl Default for HandlePrincipal
impl Eq for HandlePrincipal
Sourceimpl Hash for HandlePrincipal
impl Hash for HandlePrincipal
Sourceimpl Message for HandlePrincipal
impl Message for HandlePrincipal
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for HandlePrincipal
impl PartialEq for HandlePrincipal
impl StructuralPartialEq for HandlePrincipal