pub struct HarnessPreference {
pub harness: String,
pub category: String,
pub decision: i32,
pub verified_at: Option<Timestamp>,
}Fields
harness: Stringcategory: Stringdecision: i32verified_at: Option<Timestamp>Implementations
Sourceimpl HarnessPreference
impl HarnessPreference
Sourcepub fn decision(&self) -> PermissionDecisionKind
pub fn decision(&self) -> PermissionDecisionKind
Returns the enum value of decision, or the default if the field is set to an invalid enum value.
Sourcepub fn set_decision(&mut self, value: PermissionDecisionKind)
pub fn set_decision(&mut self, value: PermissionDecisionKind)
Sets decision to the provided enum value.