pub struct ImportCommitFailure {
pub ordinal: u64,
pub commit_hash: Option<String>,
}Expand description
Exact source commit being converted when an import failed. The ordinal is sufficient identity even if malformed source data prevents reading a hash.
Fields
ordinal: u64commit_hash: Option<String>Implementations
Sourceimpl ImportCommitFailure
impl ImportCommitFailure
Sourcepub fn commit_hash(&self) -> &str
pub fn commit_hash(&self) -> &str
Returns the value of commit_hash, or the default value if commit_hash is unset.