pub struct Invitation {
pub id: String,
pub email: String,
pub namespace_path: String,
pub role: i32,
pub invited_by: String,
pub created_at: Option<Timestamp>,
pub expires_at: Option<Timestamp>,
pub accepted_at: Option<Timestamp>,
pub accepted_by: String,
pub metadata: String,
}Fields
id: Stringemail: Stringnamespace_path: Stringrole: i32invited_by: Stringcreated_at: Option<Timestamp>unix seconds
expires_at: Option<Timestamp>0 if no expiry
accepted_at: Option<Timestamp>0 if pending
accepted_by: String“” if pending
metadata: Stringstringified JSON — small, avoids pulling in struct
Implementations
Sourceimpl Invitation
impl Invitation
Sourcepub fn role(&self) -> HostedRole
pub fn role(&self) -> HostedRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: HostedRole)
pub fn set_role(&mut self, value: HostedRole)
Sets role to the provided enum value.