pub struct InvitationSummary {
pub exists: bool,
pub valid: bool,
pub namespace_path: String,
pub namespace_name: String,
pub role: i32,
}Fields
exists: boolvalid: boolfalse if revoked, accepted, or expired
namespace_path: Stringnamespace_name: Stringmay be empty if metadata has no display name
role: i32Intentionally NO email or invited_by — don’t leak PII.
Implementations
Sourceimpl InvitationSummary
impl InvitationSummary
Sourcepub fn role(&self) -> HostedRole
pub fn role(&self) -> HostedRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: HostedRole)
pub fn set_role(&mut self, value: HostedRole)
Sets role to the provided enum value.