pub struct ListByThreadRefRequest {
pub repo_path: Option<RepositoryRef>,
pub thread_ref: String,
pub status: i32,
pub kind: i32,
pub page_size: u32,
pub page_token: String,
}Fields
repo_path: Option<RepositoryRef>thread_ref: Stringstatus: i32UNSPECIFIED selects all discussions.
kind: i32UNSPECIFIED selects all discussion kinds.
page_size: u32Zero returns all discussions. A positive value returns at most this many discussions.
page_token: StringOpaque continuation token returned by ListByThreadRefResponse.
Implementations
Sourceimpl ListByThreadRefRequest
impl ListByThreadRefRequest
Sourcepub fn status(&self) -> DiscussionStatusFilter
pub fn status(&self) -> DiscussionStatusFilter
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: DiscussionStatusFilter)
pub fn set_status(&mut self, value: DiscussionStatusFilter)
Sets status to the provided enum value.
Sourcepub fn kind(&self) -> DiscussionKind
pub fn kind(&self) -> DiscussionKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: DiscussionKind)
pub fn set_kind(&mut self, value: DiscussionKind)
Sets kind to the provided enum value.