pub struct ListOperationsRequest {
pub states: Vec<i32>,
pub kinds: Vec<i32>,
pub batch_id: Option<OperationBatchId>,
pub page_size: u32,
pub page_token: String,
}Fields
states: Vec<i32>kinds: Vec<i32>batch_id: Option<OperationBatchId>page_size: u32page_token: StringImplementations
Sourceimpl ListOperationsRequest
impl ListOperationsRequest
Sourcepub fn states(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperationState>>
pub fn states( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperationState>>
Returns an iterator which yields the valid enum values contained in states.
Sourcepub fn push_states(&mut self, value: OperationState)
pub fn push_states(&mut self, value: OperationState)
Appends the provided enum value to states.
Sourcepub fn kinds(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperationKind>>
pub fn kinds( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperationKind>>
Returns an iterator which yields the valid enum values contained in kinds.
Sourcepub fn push_kinds(&mut self, value: OperationKind)
pub fn push_kinds(&mut self, value: OperationKind)
Appends the provided enum value to kinds.