pub struct ListThreadsRequest {
pub repo_path: Option<RepositoryRef>,
pub page_size: u32,
pub page_token: String,
pub states: Vec<i32>,
pub query: String,
pub order: i32,
}Fields
repo_path: Option<RepositoryRef>page_size: u32Zero streams all threads. A positive value streams at most this many threads.
page_token: StringOpaque continuation token returned by ListThreadsPageEnd.
states: Vec<i32>Empty selects all thread lifecycle states.
query: StringFree-text search over thread name/title. Empty disables text filtering.
order: i32UNSPECIFIED is treated as LAST_ACTIVITY_DESC.
Implementations
Sourceimpl ListThreadsRequest
impl ListThreadsRequest
Sourcepub fn states(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Kind>> ⓘ
pub fn states( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Kind>> ⓘ
Returns an iterator which yields the valid enum values contained in states.
Sourcepub fn push_states(&mut self, value: Kind)
pub fn push_states(&mut self, value: Kind)
Appends the provided enum value to states.
Sourcepub fn order(&self) -> ThreadOrder
pub fn order(&self) -> ThreadOrder
Returns the enum value of order, or the default if the field is set to an invalid enum value.
Sourcepub fn set_order(&mut self, value: ThreadOrder)
pub fn set_order(&mut self, value: ThreadOrder)
Sets order to the provided enum value.