pub struct MatchBatch {
pub domain: i32,
pub hits: Vec<SearchHit>,
}Expand description
One or more hits for a single domain section (or the merged list in union mode).
Fields
domain: i32hits: Vec<SearchHit>Implementations
Sourceimpl MatchBatch
impl MatchBatch
Sourcepub fn domain(&self) -> SearchEntityKind
pub fn domain(&self) -> SearchEntityKind
Returns the enum value of domain, or the default if the field is set to an invalid enum value.
Sourcepub fn set_domain(&mut self, value: SearchEntityKind)
pub fn set_domain(&mut self, value: SearchEntityKind)
Sets domain to the provided enum value.