pub struct NotificationDelivery {
pub channel: i32,
pub status: i32,
pub delivered_at: Option<Timestamp>,
pub error: String,
}Fields
channel: i32status: i32delivered_at: Option<Timestamp>error: StringProducer-facing failure detail; empty unless status is FAILED.
Implementations
Sourceimpl NotificationDelivery
impl NotificationDelivery
Sourcepub fn channel(&self) -> NotificationChannel
pub fn channel(&self) -> NotificationChannel
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: NotificationChannel)
pub fn set_channel(&mut self, value: NotificationChannel)
Sets channel to the provided enum value.
Sourcepub fn status(&self) -> NotificationDeliveryStatus
pub fn status(&self) -> NotificationDeliveryStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: NotificationDeliveryStatus)
pub fn set_status(&mut self, value: NotificationDeliveryStatus)
Sets status to the provided enum value.