pub struct ObjectDescriptor {
pub id: String,
pub object_type: String,
pub availability_status: i32,
pub availability_note: String,
pub attachment_kind: i32,
}Fields
id: Stringobject_type: Stringavailability_status: i32availability_note: Stringattachment_kind: i32REQUIRED iff object_type == “state_attachment”; UNSPECIFIED otherwise
Implementations
Sourceimpl ObjectDescriptor
impl ObjectDescriptor
Sourcepub fn availability_status(&self) -> ObjectAvailabilityStatus
pub fn availability_status(&self) -> ObjectAvailabilityStatus
Returns the enum value of availability_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_availability_status(&mut self, value: ObjectAvailabilityStatus)
pub fn set_availability_status(&mut self, value: ObjectAvailabilityStatus)
Sets availability_status to the provided enum value.
Sourcepub fn attachment_kind(&self) -> StateAttachmentKind
pub fn attachment_kind(&self) -> StateAttachmentKind
Returns the enum value of attachment_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_attachment_kind(&mut self, value: StateAttachmentKind)
pub fn set_attachment_kind(&mut self, value: StateAttachmentKind)
Sets attachment_kind to the provided enum value.