pub struct Operation {
pub operation_id: Option<OperationId>,
pub batch_id: Option<OperationBatchId>,
pub subject: Option<OperationSubject>,
pub submission: Option<SubmitOperationRequest>,
pub state: i32,
pub cancellation: i32,
pub sequence: u64,
pub progress: Option<OperationProgress>,
pub error: Option<OperationError>,
pub result: Option<OperationResult>,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
operation_id: Option<OperationId>batch_id: Option<OperationBatchId>subject: Option<OperationSubject>submission: Option<SubmitOperationRequest>state: i32cancellation: i32sequence: u64Per-operation durable sequence. It starts at one and strictly increases for every persisted state change, including the transition to a terminal state. The terminal snapshot is then frozen.
progress: Option<OperationProgress>error: Option<OperationError>Present exactly when state is OPERATION_STATE_FAILED.
result: Option<OperationResult>Present only for a completed kind that defines a domain result.
created_at: Option<Timestamp>updated_at: Option<Timestamp>Implementations
Sourceimpl Operation
impl Operation
Sourcepub fn state(&self) -> OperationState
pub fn state(&self) -> OperationState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: OperationState)
pub fn set_state(&mut self, value: OperationState)
Sets state to the provided enum value.
Sourcepub fn cancellation(&self) -> OperationCancellation
pub fn cancellation(&self) -> OperationCancellation
Returns the enum value of cancellation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_cancellation(&mut self, value: OperationCancellation)
pub fn set_cancellation(&mut self, value: OperationCancellation)
Sets cancellation to the provided enum value.