pub struct OwnerAuthorizationBundle {
pub owner_root: Option<SignedOwnerRoot>,
pub owner_state_chain: Vec<SignedOwnerKeyTransition>,
pub capability_chain: Vec<SignedOwnerCapability>,
pub subject_biscuit: Vec<u8>,
}Fields
owner_root: Option<SignedOwnerRoot>owner_state_chain: Vec<SignedOwnerKeyTransition>capability_chain: Vec<SignedOwnerCapability>subject_biscuit: Vec<u8>A subject-signed Biscuit whose authority facts are a subset of the leaf capability and match its subject key, kind, and id.