pub struct OwnerClaimChallenge {
pub challenge_id: String,
pub stable_owner_uuid: Vec<u8>,
pub challenge_nonce: Vec<u8>,
pub expires_at_unix_seconds: i64,
}Fields
challenge_id: Stringstable_owner_uuid: Vec<u8>challenge_nonce: Vec<u8>Exactly 32 random, single-use bytes.
expires_at_unix_seconds: i64Trait Implementations
Sourceimpl Clone for OwnerClaimChallenge
impl Clone for OwnerClaimChallenge
Sourcefn clone(&self) -> OwnerClaimChallenge
fn clone(&self) -> OwnerClaimChallenge
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnerClaimChallenge
impl Debug for OwnerClaimChallenge
Sourceimpl Default for OwnerClaimChallenge
impl Default for OwnerClaimChallenge
impl Eq for OwnerClaimChallenge
Sourceimpl Hash for OwnerClaimChallenge
impl Hash for OwnerClaimChallenge
Sourceimpl Message for OwnerClaimChallenge
impl Message for OwnerClaimChallenge
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OwnerClaimChallenge
impl PartialEq for OwnerClaimChallenge
impl StructuralPartialEq for OwnerClaimChallenge