pub struct OwnerKeyTransition {
pub format_version: u32,
pub owner_id: Vec<u8>,
pub previous_state_hash: Vec<u8>,
pub sequence: u64,
pub kind: i32,
pub next_authority_key: Option<AuthorizationVerificationKey>,
pub next_recovery_policy: Option<RecoveryPolicy>,
pub valid_from_unix_seconds: i64,
pub previous_key_valid_until_unix_seconds: i64,
pub nonce: Vec<u8>,
}Fields
format_version: u32Exactly 1.
owner_id: Vec<u8>previous_state_hash: Vec<u8>sequence: u64Exactly the previous sequence plus one.
kind: i32next_recovery_policy: Option<RecoveryPolicy>valid_from_unix_seconds: i64previous_key_valid_until_unix_seconds: i64A bounded handover no longer than the maximum capability TTL. Recovery after suspected compromise uses no overlap.
nonce: Vec<u8>Exactly 32 random bytes.
Implementations
Sourceimpl OwnerKeyTransition
impl OwnerKeyTransition
Sourcepub fn kind(&self) -> OwnerKeyTransitionKind
pub fn kind(&self) -> OwnerKeyTransitionKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: OwnerKeyTransitionKind)
pub fn set_kind(&mut self, value: OwnerKeyTransitionKind)
Sets kind to the provided enum value.