pub struct ProvenanceFileSummary {
pub path: String,
pub status: i32,
pub summary: Option<BlameSummary>,
pub authored_line_count: u32,
}Fields
path: Stringstatus: i32summary: Option<BlameSummary>Implementations
Sourceimpl ProvenanceFileSummary
impl ProvenanceFileSummary
Sourcepub fn status(&self) -> ProvenanceFileStatus
pub fn status(&self) -> ProvenanceFileStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ProvenanceFileStatus)
pub fn set_status(&mut self, value: ProvenanceFileStatus)
Sets status to the provided enum value.