pub struct ProviderPlanChallenge {
pub version: u32,
pub plan_nonce: Vec<u8>,
pub grant_batch_digest: Vec<u8>,
pub summary: Option<ProviderPlanSummary>,
}Expand description
Phase two of client-authorized exact-plan negotiation. The digest is a domain-separated BLAKE3 digest over the complete private grant batch. R2 keys, ETags, and source offsets remain server-to-Worker data.
Fields
version: u32plan_nonce: Vec<u8>grant_batch_digest: Vec<u8>summary: Option<ProviderPlanSummary>Trait Implementations
Sourceimpl Clone for ProviderPlanChallenge
impl Clone for ProviderPlanChallenge
Sourcefn clone(&self) -> ProviderPlanChallenge
fn clone(&self) -> ProviderPlanChallenge
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderPlanChallenge
impl Debug for ProviderPlanChallenge
Sourceimpl Default for ProviderPlanChallenge
impl Default for ProviderPlanChallenge
impl Eq for ProviderPlanChallenge
Sourceimpl Hash for ProviderPlanChallenge
impl Hash for ProviderPlanChallenge
Sourceimpl Message for ProviderPlanChallenge
impl Message for ProviderPlanChallenge
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProviderPlanChallenge
impl PartialEq for ProviderPlanChallenge
impl StructuralPartialEq for ProviderPlanChallenge