pub struct ProviderPullResponse {
pub version: u32,
pub plan_nonce: Vec<u8>,
pub grant_batch_digest: Vec<u8>,
pub status: i32,
pub pack_digest: Vec<u8>,
}Expand description
Result of the provider attempt. COMPLETE carries the exact BLAKE3 trailer written into the virtual LMPK. FALLBACK asks Weft to continue the same authorized multi-Want pull on its existing stream.
Fields
version: u32plan_nonce: Vec<u8>grant_batch_digest: Vec<u8>status: i32pack_digest: Vec<u8>Implementations
Sourceimpl ProviderPullResponse
impl ProviderPullResponse
Sourcepub fn status(&self) -> ProviderPullResultStatus
pub fn status(&self) -> ProviderPullResultStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ProviderPullResultStatus)
pub fn set_status(&mut self, value: ProviderPullResultStatus)
Sets status to the provided enum value.