pub struct ProviderReadCheckpoint {
pub attempt_generation: u64,
pub acknowledged_length: u64,
pub final_digest: Vec<u8>,
}Expand description
Checkpoints count verified bytes within this opaque extent. A final checkpoint is accepted only when final_digest is the exact 32-byte BLAKE3 digest of the complete retained prefix plus received suffix.
Fields
attempt_generation: u64acknowledged_length: u64final_digest: Vec<u8>Trait Implementations
Sourceimpl Clone for ProviderReadCheckpoint
impl Clone for ProviderReadCheckpoint
Sourcefn clone(&self) -> ProviderReadCheckpoint
fn clone(&self) -> ProviderReadCheckpoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderReadCheckpoint
impl Debug for ProviderReadCheckpoint
Sourceimpl Default for ProviderReadCheckpoint
impl Default for ProviderReadCheckpoint
impl Eq for ProviderReadCheckpoint
Sourceimpl Hash for ProviderReadCheckpoint
impl Hash for ProviderReadCheckpoint
Sourceimpl Message for ProviderReadCheckpoint
impl Message for ProviderReadCheckpoint
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProviderReadCheckpoint
impl PartialEq for ProviderReadCheckpoint
impl StructuralPartialEq for ProviderReadCheckpoint