pub struct ProviderTokenImportSource {
pub provider: i32,
pub full_name: String,
}Fields
provider: i32full_name: StringImplementations
Sourceimpl ProviderTokenImportSource
impl ProviderTokenImportSource
Sourcepub fn provider(&self) -> ImportProvider
pub fn provider(&self) -> ImportProvider
Returns the enum value of provider, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provider(&mut self, value: ImportProvider)
pub fn set_provider(&mut self, value: ImportProvider)
Sets provider to the provided enum value.