pub struct PushRequest {
pub repo_path: Option<RepositoryRef>,
pub local_state: Option<StateId>,
pub target_thread: String,
pub create_thread: bool,
pub force: bool,
pub objects: Vec<ObjectDescriptor>,
pub transfer: Option<TransferCheckpoint>,
pub partial_fetch_status: i32,
pub allow_partial_fetch: bool,
pub thread_metadata: Option<ThreadMetadata>,
pub local_revision_address: String,
}Fields
repo_path: Option<RepositoryRef>local_state: Option<StateId>target_thread: Stringcreate_thread: boolforce: boolobjects: Vec<ObjectDescriptor>transfer: Option<TransferCheckpoint>partial_fetch_status: i32allow_partial_fetch: boolthread_metadata: Option<ThreadMetadata>local_revision_address: StringExplicit revision being published. Native repos use heddle:<state_id>;
git-overlay repos use git:<commit_oid> and stream Git objects on the Git
lane rather than importing the commit as a Heddle state.
Idempotency on the stream-opening message. The PushMessage envelope itself isn’t the operation — PushRequest is.
Implementations
Sourceimpl PushRequest
impl PushRequest
Sourcepub fn partial_fetch_status(&self) -> PartialFetchStatus
pub fn partial_fetch_status(&self) -> PartialFetchStatus
Returns the enum value of partial_fetch_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_partial_fetch_status(&mut self, value: PartialFetchStatus)
pub fn set_partial_fetch_status(&mut self, value: PartialFetchStatus)
Sets partial_fetch_status to the provided enum value.