pub struct RecordInteractionRequest {
pub kind: i32,
pub resource_path: String,
pub feed_item_id: String,
pub client_operation_id: String,
}Fields
kind: i32Subject (user) is resolved server-side from the authenticated Biscuit claim.
resource_path: Stringe.g. “luke/objects/-/changes/abc123”
feed_item_id: Stringoptional: the feed item that led to this interaction
client_operation_id: StringImplementations
Sourceimpl RecordInteractionRequest
impl RecordInteractionRequest
Sourcepub fn kind(&self) -> InteractionKind
pub fn kind(&self) -> InteractionKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: InteractionKind)
pub fn set_kind(&mut self, value: InteractionKind)
Sets kind to the provided enum value.