pub struct RecoveryGuardian {
pub kind: i32,
pub key: Option<AuthorizationVerificationKey>,
}Fields
kind: i32key: Option<AuthorizationVerificationKey>Implementations
Sourceimpl RecoveryGuardian
impl RecoveryGuardian
Sourcepub fn kind(&self) -> RecoveryGuardianKind
pub fn kind(&self) -> RecoveryGuardianKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: RecoveryGuardianKind)
pub fn set_kind(&mut self, value: RecoveryGuardianKind)
Sets kind to the provided enum value.