pub struct RedactionSidecarIdentity {
pub blob_hash: String,
}Expand description
Identity variants used only to construct the canonical operation-signing body. They do not replace the identity fields on the transfer messages.
Fields
blob_hash: StringExactly 64 lower-case hexadecimal ASCII bytes.