pub struct RemoteSyncOperationSpec {
pub repository: Option<RepositoryRef>,
pub direction: i32,
}Fields
repository: Option<RepositoryRef>direction: i32Implementations
Sourceimpl RemoteSyncOperationSpec
impl RemoteSyncOperationSpec
Sourcepub fn direction(&self) -> RemoteSyncDirection
pub fn direction(&self) -> RemoteSyncDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: RemoteSyncDirection)
pub fn set_direction(&mut self, value: RemoteSyncDirection)
Sets direction to the provided enum value.