pub struct RequestHeldNameRequest {
pub name: String,
pub client_operation_id: String,
}Fields
name: Stringclient_operation_id: StringStable retry key in the namespace of the authenticated subject and this RPC. A retry with the same authenticated subject, RPC, and client_operation_id and normalized name returns the same response without repeating the mutation. Key reuse with a different normalized name MUST fail with FAILED_PRECONDITION.