pub struct ResourceRole {
pub resource_path: String,
pub resource_kind: String,
pub role: i32,
}Expand description
A single role grant held by the caller on a namespace or repository.
Fields
resource_path: StringVisible resource path, e.g. “heddle/core-services” or “heddle”.
resource_kind: String“namespace” or “repository”.
role: i32Role name: one of “reader”, “developer”, “maintainer”, “admin”, “owner”.
Implementations
Sourceimpl ResourceRole
impl ResourceRole
Sourcepub fn role(&self) -> HostedRole
pub fn role(&self) -> HostedRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: HostedRole)
pub fn set_role(&mut self, value: HostedRole)
Sets role to the provided enum value.