pub struct ReviewPayload {
pub state_id: Option<StateId>,
pub summary: Option<ReviewSummary>,
pub agent_narrative: String,
pub partition: Option<ReadingOrderPartition>,
pub in_budget_signals: Vec<RiskSignal>,
pub all_signals: Vec<RiskSignal>,
pub tick_budget: u32,
pub discussions: Vec<AnchoredDiscussion>,
pub merge_requirements: Vec<MergeRequirement>,
pub signing_footer: Option<SigningFooter>,
}Fields
state_id: Option<StateId>summary: Option<ReviewSummary>agent_narrative: StringAgent-authored narrative captured at snapshot time. Empty when the state has no agent attribution.
partition: Option<ReadingOrderPartition>in_budget_signals: Vec<RiskSignal>all_signals: Vec<RiskSignal>Full set of fired signals; only populated when the request set
include_all_signals = true.
tick_budget: u32discussions: Vec<AnchoredDiscussion>merge_requirements: Vec<MergeRequirement>Trait Implementations
Sourceimpl Clone for ReviewPayload
impl Clone for ReviewPayload
Sourcefn clone(&self) -> ReviewPayload
fn clone(&self) -> ReviewPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReviewPayload
impl Debug for ReviewPayload
Sourceimpl Default for ReviewPayload
impl Default for ReviewPayload
Sourceimpl Message for ReviewPayload
impl Message for ReviewPayload
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReviewPayload
impl PartialEq for ReviewPayload
impl StructuralPartialEq for ReviewPayload