pub struct ReviewPrMetadata {Show 15 fields
pub title: String,
pub body: String,
pub state: Option<StateId>,
pub draft: bool,
pub changed_files: u32,
pub additions: u32,
pub deletions: u32,
pub head_sha: String,
pub base_branch: String,
pub head_branch: String,
pub author: Option<ReviewPrAuthor>,
pub labels: Vec<ReviewPrLabel>,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub merged_at: Option<Timestamp>,
}Fields
title: Stringbody: Stringstate: Option<StateId>draft: boolchanged_files: u32additions: u32deletions: u32head_sha: Stringbase_branch: Stringhead_branch: Stringlabels: Vec<ReviewPrLabel>created_at: Option<Timestamp>updated_at: Option<Timestamp>merged_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for ReviewPrMetadata
impl Clone for ReviewPrMetadata
Sourcefn clone(&self) -> ReviewPrMetadata
fn clone(&self) -> ReviewPrMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReviewPrMetadata
impl Debug for ReviewPrMetadata
Sourceimpl Default for ReviewPrMetadata
impl Default for ReviewPrMetadata
Sourceimpl Message for ReviewPrMetadata
impl Message for ReviewPrMetadata
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReviewPrMetadata
impl PartialEq for ReviewPrMetadata
impl StructuralPartialEq for ReviewPrMetadata