pub struct RiskSignal {
pub kind: i32,
pub anchor: Option<SignalAnchor>,
pub reason: String,
pub producer_module: String,
pub producer_version: u32,
pub computed_at: Option<Timestamp>,
pub visibility: i32,
}Fields
kind: i32Closed vocabulary matching objects::object::RiskSignalKind.
anchor: Option<SignalAnchor>reason: Stringproducer_module: Stringproducer_version: u32computed_at: Option<Timestamp>visibility: i32Render-time tier set by the server-side budgeter so clients render without re-budgeting.
Implementations
Sourceimpl RiskSignal
impl RiskSignal
Sourcepub fn kind(&self) -> RiskSignalKind
pub fn kind(&self) -> RiskSignalKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: RiskSignalKind)
pub fn set_kind(&mut self, value: RiskSignalKind)
Sets kind to the provided enum value.
Sourcepub fn visibility(&self) -> SignalVisibility
pub fn visibility(&self) -> SignalVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: SignalVisibility)
pub fn set_visibility(&mut self, value: SignalVisibility)
Sets visibility to the provided enum value.