pub struct ServiceContract {
pub deployment_targets: Vec<i32>,
pub maturity: i32,
}Fields
deployment_targets: Vec<i32>maturity: i32Implementations
Sourceimpl ServiceContract
impl ServiceContract
Sourcepub fn deployment_targets(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<DeploymentTarget>>
pub fn deployment_targets( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<DeploymentTarget>>
Returns an iterator which yields the valid enum values contained in deployment_targets.
Sourcepub fn push_deployment_targets(&mut self, value: DeploymentTarget)
pub fn push_deployment_targets(&mut self, value: DeploymentTarget)
Appends the provided enum value to deployment_targets.
Sourcepub fn maturity(&self) -> ServiceMaturity
pub fn maturity(&self) -> ServiceMaturity
Returns the enum value of maturity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_maturity(&mut self, value: ServiceMaturity)
pub fn set_maturity(&mut self, value: ServiceMaturity)
Sets maturity to the provided enum value.