pub struct SetContextRequest {
pub repo_path: Option<RepositoryRef>,
pub path: String,
pub scope: Option<AnnotationScope>,
pub tags: Vec<String>,
pub content: String,
pub agent_provider: String,
pub agent_model: String,
pub target_state_id: Option<StateId>,
pub kind: i32,
pub client_operation_id: String,
}Fields
repo_path: Option<RepositoryRef>path: Stringscope: Option<AnnotationScope>content: Stringagent_provider: Stringagent_model: Stringtarget_state_id: Option<StateId>kind: i32client_operation_id: StringImplementations
Sourceimpl SetContextRequest
impl SetContextRequest
Sourcepub fn kind(&self) -> ContextAnnotationKind
pub fn kind(&self) -> ContextAnnotationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ContextAnnotationKind)
pub fn set_kind(&mut self, value: ContextAnnotationKind)
Sets kind to the provided enum value.