pub struct SetNamespaceVisibilityRequest {
pub full_path: String,
pub visibility: i32,
pub client_operation_id: String,
}Fields
full_path: Stringvisibility: i32client_operation_id: StringImplementations
Sourceimpl SetNamespaceVisibilityRequest
impl SetNamespaceVisibilityRequest
Sourcepub fn visibility(&self) -> SpoolVisibility
pub fn visibility(&self) -> SpoolVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: SpoolVisibility)
pub fn set_visibility(&mut self, value: SpoolVisibility)
Sets visibility to the provided enum value.