pub struct SignedOwnerKeyTransition {
pub transition: Option<OwnerKeyTransition>,
pub authorizations: Vec<AuthorizationSignature>,
pub next_authority_key_proof: Option<AuthorizationSignature>,
pub next_recovery_key_proofs: Vec<AuthorizationSignature>,
}Expand description
Authorizations sign canonical_owner_key_transition_v1(transition).
ROTATE requires the current authority and next key. RECOVER requires the current recovery threshold and next key. RECOVERY_POLICY requires the current authority, current recovery threshold, and possession proofs from every next guardian. CLAIM_DEFERRED_HUMAN requires the origin key, the next human authority key, and every next guardian.
Fields
transition: Option<OwnerKeyTransition>next_recovery_key_proofs: Vec<AuthorizationSignature>Trait Implementations
Sourceimpl Clone for SignedOwnerKeyTransition
impl Clone for SignedOwnerKeyTransition
Sourcefn clone(&self) -> SignedOwnerKeyTransition
fn clone(&self) -> SignedOwnerKeyTransition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedOwnerKeyTransition
impl Debug for SignedOwnerKeyTransition
Sourceimpl Default for SignedOwnerKeyTransition
impl Default for SignedOwnerKeyTransition
Sourceimpl Message for SignedOwnerKeyTransition
impl Message for SignedOwnerKeyTransition
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SignedOwnerKeyTransition
impl PartialEq for SignedOwnerKeyTransition
impl StructuralPartialEq for SignedOwnerKeyTransition