pub struct SignedOwnerRoot {
pub root: Option<OwnerRoot>,
pub authority_proof: Option<AuthorizationSignature>,
pub recovery_key_proofs: Vec<AuthorizationSignature>,
}Fields
root: Option<OwnerRoot>The root authority key signs canonical_owner_root_v1(root).
recovery_key_proofs: Vec<AuthorizationSignature>Every declared guardian signs the same canonical root body as proof that the recovery signing material was present at declaration.