pub struct SpoolOwnerGenesis {
pub spool_uuid: Vec<u8>,
pub owner_public_key: Option<AuthorizationVerificationKey>,
}Expand description
Immutable owner-key binding created with a spool. spool_uuid is the raw
16-byte UUIDv7 that is also the spool id. owner_public_key is the owner
authority key at creation; no registry key or nonce participates.
Fields
spool_uuid: Vec<u8>owner_public_key: Option<AuthorizationVerificationKey>Trait Implementations
Sourceimpl Clone for SpoolOwnerGenesis
impl Clone for SpoolOwnerGenesis
Sourcefn clone(&self) -> SpoolOwnerGenesis
fn clone(&self) -> SpoolOwnerGenesis
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpoolOwnerGenesis
impl Debug for SpoolOwnerGenesis
Sourceimpl Default for SpoolOwnerGenesis
impl Default for SpoolOwnerGenesis
impl Eq for SpoolOwnerGenesis
Sourceimpl Hash for SpoolOwnerGenesis
impl Hash for SpoolOwnerGenesis
Sourceimpl Message for SpoolOwnerGenesis
impl Message for SpoolOwnerGenesis
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SpoolOwnerGenesis
impl PartialEq for SpoolOwnerGenesis
impl StructuralPartialEq for SpoolOwnerGenesis