pub struct StateSummary {
pub state_id: Option<StateId>,
pub parents: Vec<Vec<u8>>,
pub intent: String,
pub created_at: Option<Timestamp>,
pub principal: Option<StatePrincipal>,
pub agent: Option<StateAgent>,
pub confidence: Option<f32>,
pub status: i32,
pub verification: Option<StateVerification>,
pub change_id: Option<ChangeId>,
}Fields
state_id: Option<StateId>parents: Vec<Vec<u8>>intent: Stringcreated_at: Option<Timestamp>principal: Option<StatePrincipal>agent: Option<StateAgent>confidence: Option<f32>status: i32verification: Option<StateVerification>change_id: Option<ChangeId>Implementations
Sourceimpl StateSummary
impl StateSummary
Sourcepub fn confidence(&self) -> f32
pub fn confidence(&self) -> f32
Returns the value of confidence, or the default value if confidence is unset.
Sourcepub fn status(&self) -> StateStatus
pub fn status(&self) -> StateStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: StateStatus)
pub fn set_status(&mut self, value: StateStatus)
Sets status to the provided enum value.