pub struct StateVisibilityTransfer {
pub state_id: Option<StateId>,
pub state_visibility_blob: Vec<u8>,
}Expand description
Out-of-pack transport for state-visibility sidecars. State visibility
records live outside .heddle/objects/ and are keyed by the state id
whose audience tier they declare.
state_id is the hex-encoded ChangeId of the state.
state_visibility_blob is the rmp-encoded StateVisibilityBlob byte
payload.
Fields
state_id: Option<StateId>state_visibility_blob: Vec<u8>Trait Implementations
Sourceimpl Clone for StateVisibilityTransfer
impl Clone for StateVisibilityTransfer
Sourcefn clone(&self) -> StateVisibilityTransfer
fn clone(&self) -> StateVisibilityTransfer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateVisibilityTransfer
impl Debug for StateVisibilityTransfer
Sourceimpl Default for StateVisibilityTransfer
impl Default for StateVisibilityTransfer
impl Eq for StateVisibilityTransfer
Sourceimpl Hash for StateVisibilityTransfer
impl Hash for StateVisibilityTransfer
Sourceimpl Message for StateVisibilityTransfer
impl Message for StateVisibilityTransfer
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StateVisibilityTransfer
impl PartialEq for StateVisibilityTransfer
impl StructuralPartialEq for StateVisibilityTransfer