pub struct SubmitOperationRequest {
pub kind: i32,
pub client_operation_id: String,
pub details: Option<Details>,
}Fields
kind: i32client_operation_id: StringStable across ambiguous-response retries. For a given authenticated subject and kind, this value identifies exactly one operation.
details: Option<Details>Implementations
Sourceimpl SubmitOperationRequest
impl SubmitOperationRequest
Sourcepub fn kind(&self) -> OperationKind
pub fn kind(&self) -> OperationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: OperationKind)
pub fn set_kind(&mut self, value: OperationKind)
Sets kind to the provided enum value.