pub struct SubscribeNotificationsRequest {
pub resume_after_id: String,
pub kinds: Vec<i32>,
pub repo_paths: Vec<RepositoryRef>,
}Fields
resume_after_id: StringResume token: the notification_id of the last received Notification. On reconnect the server replays notifications after it, then streams live. Empty streams only new notifications from “now” with no catch-up.
kinds: Vec<i32>Optional: only these kinds.
repo_paths: Vec<RepositoryRef>Optional: only these repos.
Implementations
Sourceimpl SubscribeNotificationsRequest
impl SubscribeNotificationsRequest
Sourcepub fn kinds(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<NotificationKind>> ⓘ
pub fn kinds( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<NotificationKind>> ⓘ
Returns an iterator which yields the valid enum values contained in kinds.
Sourcepub fn push_kinds(&mut self, value: NotificationKind)
pub fn push_kinds(&mut self, value: NotificationKind)
Appends the provided enum value to kinds.