pub struct TimelineOperationReceipt {
pub operation_id: Option<TimelineOperationId>,
pub disposition: i32,
pub reason: String,
pub hosted_high_water_cursor: String,
}Fields
operation_id: Option<TimelineOperationId>disposition: i32reason: Stringhosted_high_water_cursor: StringImplementations
Sourceimpl TimelineOperationReceipt
impl TimelineOperationReceipt
Sourcepub fn disposition(&self) -> TimelineOperationDisposition
pub fn disposition(&self) -> TimelineOperationDisposition
Returns the enum value of disposition, or the default if the field is set to an invalid enum value.
Sourcepub fn set_disposition(&mut self, value: TimelineOperationDisposition)
pub fn set_disposition(&mut self, value: TimelineOperationDisposition)
Sets disposition to the provided enum value.