pub struct TreadleTargetEnvironment {
pub oci_image_digest: String,
pub platform: Option<TreadlePlatform>,
}Expand description
Required, authoritative environment for one concrete check.
Fields
oci_image_digest: StringImmutable OCI image digest, exactly “sha256:” plus 64 lowercase hex digits. This is a digest, not a tag or a name containing a tag.
platform: Option<TreadlePlatform>Trait Implementations
Sourceimpl Clone for TreadleTargetEnvironment
impl Clone for TreadleTargetEnvironment
Sourcefn clone(&self) -> TreadleTargetEnvironment
fn clone(&self) -> TreadleTargetEnvironment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TreadleTargetEnvironment
impl Debug for TreadleTargetEnvironment
Sourceimpl Default for TreadleTargetEnvironment
impl Default for TreadleTargetEnvironment
impl Eq for TreadleTargetEnvironment
Sourceimpl Hash for TreadleTargetEnvironment
impl Hash for TreadleTargetEnvironment
Sourceimpl Message for TreadleTargetEnvironment
impl Message for TreadleTargetEnvironment
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TreadleTargetEnvironment
impl PartialEq for TreadleTargetEnvironment
impl StructuralPartialEq for TreadleTargetEnvironment