pub struct UpdateAgentPolicyRequest {
pub repository: Option<RepositoryRef>,
pub visibility: i32,
pub structured_retention: i32,
pub raw_diagnostic_retention: i32,
pub client_operation_id: String,
}Fields
repository: Option<RepositoryRef>visibility: i32structured_retention: i32raw_diagnostic_retention: i32client_operation_id: StringImplementations
Sourceimpl UpdateAgentPolicyRequest
impl UpdateAgentPolicyRequest
Sourcepub fn visibility(&self) -> AgentVisibility
pub fn visibility(&self) -> AgentVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: AgentVisibility)
pub fn set_visibility(&mut self, value: AgentVisibility)
Sets visibility to the provided enum value.
Sourcepub fn structured_retention(&self) -> StructuredRetention
pub fn structured_retention(&self) -> StructuredRetention
Returns the enum value of structured_retention, or the default if the field is set to an invalid enum value.
Sourcepub fn set_structured_retention(&mut self, value: StructuredRetention)
pub fn set_structured_retention(&mut self, value: StructuredRetention)
Sets structured_retention to the provided enum value.
Sourcepub fn raw_diagnostic_retention(&self) -> RawDiagnosticRetention
pub fn raw_diagnostic_retention(&self) -> RawDiagnosticRetention
Returns the enum value of raw_diagnostic_retention, or the default if the field is set to an invalid enum value.
Sourcepub fn set_raw_diagnostic_retention(&mut self, value: RawDiagnosticRetention)
pub fn set_raw_diagnostic_retention(&mut self, value: RawDiagnosticRetention)
Sets raw_diagnostic_retention to the provided enum value.