pub struct UpdateFeedItemRequest {
pub item_id: String,
pub resolution: i32,
pub client_operation_id: String,
}Fields
item_id: Stringresolution: i32dismiss, pin, mark acted_on
client_operation_id: StringImplementations
Sourceimpl UpdateFeedItemRequest
impl UpdateFeedItemRequest
Sourcepub fn resolution(&self) -> FeedItemResolution
pub fn resolution(&self) -> FeedItemResolution
Returns the enum value of resolution, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resolution(&mut self, value: FeedItemResolution)
pub fn set_resolution(&mut self, value: FeedItemResolution)
Sets resolution to the provided enum value.