pub struct UpdateRefRequest {
pub repo_path: Option<RepositoryRef>,
pub name: String,
pub is_thread: bool,
pub force: bool,
pub old_value: String,
pub new_value: String,
pub thread_metadata: Option<ThreadMetadata>,
pub old_revision_address: String,
pub new_revision_address: String,
pub client_operation_id: String,
}Fields
repo_path: Option<RepositoryRef>name: Stringis_thread: boolforce: boolold_value: Stringnew_value: Stringthread_metadata: Option<ThreadMetadata>old_revision_address: StringExplicit two-lane revision addresses. Native callers should send
heddle:<state_id> here; git-overlay callers send git:<commit_oid>.
old_value / new_value remain populated for Heddle-native refs.
new_revision_address: Stringclient_operation_id: StringTrait Implementations
Sourceimpl Clone for UpdateRefRequest
impl Clone for UpdateRefRequest
Sourcefn clone(&self) -> UpdateRefRequest
fn clone(&self) -> UpdateRefRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateRefRequest
impl Debug for UpdateRefRequest
Sourceimpl Default for UpdateRefRequest
impl Default for UpdateRefRequest
Sourceimpl Message for UpdateRefRequest
impl Message for UpdateRefRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateRefRequest
impl PartialEq for UpdateRefRequest
impl StructuralPartialEq for UpdateRefRequest