pub struct UpdateSpoolSettingsRequest {
pub full_path: String,
pub settings: Option<SpoolSettings>,
pub client_operation_id: String,
}Expand description
General settings write for any spool (description, etc.). Carries the whole SpoolSettings for forward-compat; the server enforces which fields are settable (e.g. description). Reuses the existing SpoolSettings message.
Fields
full_path: Stringsettings: Option<SpoolSettings>client_operation_id: StringTrait Implementations
Sourceimpl Clone for UpdateSpoolSettingsRequest
impl Clone for UpdateSpoolSettingsRequest
Sourcefn clone(&self) -> UpdateSpoolSettingsRequest
fn clone(&self) -> UpdateSpoolSettingsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateSpoolSettingsRequest
impl Debug for UpdateSpoolSettingsRequest
Sourceimpl Default for UpdateSpoolSettingsRequest
impl Default for UpdateSpoolSettingsRequest
impl Eq for UpdateSpoolSettingsRequest
Sourceimpl Hash for UpdateSpoolSettingsRequest
impl Hash for UpdateSpoolSettingsRequest
Sourceimpl Message for UpdateSpoolSettingsRequest
impl Message for UpdateSpoolSettingsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for UpdateSpoolSettingsRequest