pub struct VerifiedArtifactSignature {
pub signature_id: String,
pub signer_subject: String,
pub signer_display_name: String,
pub actor_kind: i32,
pub signer_public_key: Vec<u8>,
pub signed_at: Option<Timestamp>,
}Expand description
One signature that survived cryptographic envelope verification, artifact binding, subject/key binding, and current key-revocation checks. Weft omits any row that fails any check.
Fields
signature_id: Stringsigner_subject: Stringsigner_display_name: Stringactor_kind: i32signer_public_key: Vec<u8>signed_at: Option<Timestamp>Implementations
Sourceimpl VerifiedArtifactSignature
impl VerifiedArtifactSignature
Sourcepub fn actor_kind(&self) -> SignatureActorKind
pub fn actor_kind(&self) -> SignatureActorKind
Returns the enum value of actor_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_actor_kind(&mut self, value: SignatureActorKind)
pub fn set_actor_kind(&mut self, value: SignatureActorKind)
Sets actor_kind to the provided enum value.