pub struct VetoRecoveryRequest {
pub recovery_attempt_id: String,
pub veto_token: String,
pub client_operation_id: String,
}Expand description
Cancel an in-flight recovery attempt from an existing device. weft#183.
Fields
recovery_attempt_id: Stringveto_token: StringThe veto bearer token surfaced to the user’s existing devices by BeginRecovery. Authorizes the cancel; valid only within the window.
client_operation_id: StringTrait Implementations
Sourceimpl Clone for VetoRecoveryRequest
impl Clone for VetoRecoveryRequest
Sourcefn clone(&self) -> VetoRecoveryRequest
fn clone(&self) -> VetoRecoveryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VetoRecoveryRequest
impl Debug for VetoRecoveryRequest
Sourceimpl Default for VetoRecoveryRequest
impl Default for VetoRecoveryRequest
impl Eq for VetoRecoveryRequest
Sourceimpl Hash for VetoRecoveryRequest
impl Hash for VetoRecoveryRequest
Sourceimpl Message for VetoRecoveryRequest
impl Message for VetoRecoveryRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VetoRecoveryRequest
impl PartialEq for VetoRecoveryRequest
impl StructuralPartialEq for VetoRecoveryRequest