#[repr(i32)]pub enum ProviderRepositorySizeEstimateState {
Unknown = 0,
Available = 1,
}Expand description
Advisory Git storage estimate, never converted result bytes or authority.
Variants
Implementations
Sourceimpl ProviderRepositorySizeEstimateState
impl ProviderRepositorySizeEstimateState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProviderRepositorySizeEstimateState.
Sourcepub fn from_i32(value: i32) -> Option<ProviderRepositorySizeEstimateState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProviderRepositorySizeEstimateState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ProviderRepositorySizeEstimateState, or None if value is not a valid variant.
Sourceimpl ProviderRepositorySizeEstimateState
impl ProviderRepositorySizeEstimateState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.