#[repr(i32)]pub enum SourcePathKind {
Unspecified = 0,
File = 1,
Directory = 2,
}Expand description
Unknown, including a missing path at the exact revision. Never infer from extensions, line numbers, the working tree or the current Thread head.
Variants
Implementations
Sourceimpl SourcePathKind
impl SourcePathKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.