pub struct BehaviorAssignment {
pub id: String,
pub operation_id: String,
pub target: String,
pub kind: i32,
pub value_id: String,
pub source: Option<BehaviorSource>,
pub provenance: i32,
}Fields
id: Stringoperation_id: Stringtarget: StringSyntactic address (e.g. SavePlan.git_scope), not inferred type resolution.
kind: i32value_id: Stringsource: Option<BehaviorSource>provenance: i32Implementations
Sourceimpl BehaviorAssignment
impl BehaviorAssignment
Sourcepub fn kind(&self) -> Kind
pub fn kind(&self) -> Kind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn provenance(&self) -> BehaviorProvenance
pub fn provenance(&self) -> BehaviorProvenance
Returns the enum value of provenance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provenance(&mut self, value: BehaviorProvenance)
pub fn set_provenance(&mut self, value: BehaviorProvenance)
Sets provenance to the provided enum value.