pub struct BehaviorExpression {
pub id: String,
pub source: Option<BehaviorSource>,
pub normalized_hash: Vec<u8>,
pub conditional: Option<BehaviorConditional>,
pub provenance: i32,
}Fields
id: Stringsource: Option<BehaviorSource>normalized_hash: Vec<u8>Existing length-framed non-comment token normalization; not an effects hash.
conditional: Option<BehaviorConditional>provenance: i32Implementations
Sourceimpl BehaviorExpression
impl BehaviorExpression
Sourcepub fn provenance(&self) -> BehaviorProvenance
pub fn provenance(&self) -> BehaviorProvenance
Returns the enum value of provenance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provenance(&mut self, value: BehaviorProvenance)
pub fn set_provenance(&mut self, value: BehaviorProvenance)
Sets provenance to the provided enum value.