pub struct CheckoutOverview {
pub ref: Option<CheckoutRef>,
pub thread: Option<ThreadRef>,
pub version: Vec<u8>,
pub materialized: Option<RevisionRef>,
pub dirty: bool,
pub changed_paths: u64,
pub requirements: Vec<Requirement>,
pub actions: Vec<ActionAvailability>,
pub active_run: Option<RecordRef>,
pub display_path: String,
pub conflicts: Option<SourceConflictSet>,
}Fields
ref: Option<CheckoutRef>thread: Option<ThreadRef>version: Vec<u8>materialized: Option<RevisionRef>dirty: boolchanged_paths: u64requirements: Vec<Requirement>actions: Vec<ActionAvailability>active_run: Option<RecordRef>display_path: StringDisplay only, disclosed solely under device authority.
conflicts: Option<SourceConflictSet>Trait Implementations
Sourceimpl Clone for CheckoutOverview
impl Clone for CheckoutOverview
Sourceimpl Debug for CheckoutOverview
impl Debug for CheckoutOverview
Sourceimpl Default for CheckoutOverview
impl Default for CheckoutOverview
Sourceimpl Message for CheckoutOverview
impl Message for CheckoutOverview
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CheckoutOverview
impl PartialEq for CheckoutOverview
impl StructuralPartialEq for CheckoutOverview