pub struct InvitationResolution {
pub status: i32,
pub spool: Option<SpoolAddress>,
pub spool_name: String,
pub role: i32,
pub expires_at: Option<Timestamp>,
}Fields
status: i32spool: Option<SpoolAddress>spool_name: Stringrole: i32expires_at: Option<Timestamp>Implementations
Sourceimpl InvitationResolution
impl InvitationResolution
Sourcepub fn status(&self) -> Status
pub fn status(&self) -> Status
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: Status)
pub fn set_status(&mut self, value: Status)
Sets status to the provided enum value.
Sourcepub fn role(&self) -> ResourceRole
pub fn role(&self) -> ResourceRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: ResourceRole)
pub fn set_role(&mut self, value: ResourceRole)
Sets role to the provided enum value.