pub struct ObserveOperationsRequest {
pub spools: Vec<SpoolRef>,
pub operations: Vec<RecordRef>,
pub client_operation_ids: Vec<String>,
pub page: Option<PageRequest>,
pub observe: Option<ObserveOptions>,
}Fields
spools: Vec<SpoolRef>operations: Vec<RecordRef>client_operation_ids: Vec<String>Recover ambiguous outcomes without submitting a second mutation. Search is confined to the authenticated caller’s declared operation-ID namespace.
page: Option<PageRequest>observe: Option<ObserveOptions>Trait Implementations
Sourceimpl Clone for ObserveOperationsRequest
impl Clone for ObserveOperationsRequest
Sourceimpl Debug for ObserveOperationsRequest
impl Debug for ObserveOperationsRequest
Sourceimpl Default for ObserveOperationsRequest
impl Default for ObserveOperationsRequest
Sourceimpl Message for ObserveOperationsRequest
impl Message for ObserveOperationsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ObserveOperationsRequest
impl PartialEq for ObserveOperationsRequest
impl StructuralPartialEq for ObserveOperationsRequest