pub struct ObserveWorkspaceRequest {
pub threads: Option<ThreadQuery>,
pub pages: Option<WorkspacePages>,
pub observe: Option<ObserveOptions>,
pub include_attention: bool,
pub include_operations: bool,
pub include_devices: bool,
pub include_bookmarks: bool,
}Fields
threads: Option<ThreadQuery>pages: Option<WorkspacePages>observe: Option<ObserveOptions>include_attention: boolinclude_operations: boolinclude_devices: boolinclude_bookmarks: boolTrait Implementations
Sourceimpl Clone for ObserveWorkspaceRequest
impl Clone for ObserveWorkspaceRequest
Sourceimpl Debug for ObserveWorkspaceRequest
impl Debug for ObserveWorkspaceRequest
Sourceimpl Default for ObserveWorkspaceRequest
impl Default for ObserveWorkspaceRequest
Sourceimpl Message for ObserveWorkspaceRequest
impl Message for ObserveWorkspaceRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ObserveWorkspaceRequest
impl PartialEq for ObserveWorkspaceRequest
impl StructuralPartialEq for ObserveWorkspaceRequest