pub struct SemanticIndexObject {
pub hash: Vec<u8>,
pub canonical: Vec<u8>,
}Expand description
One existing Heddle semantic root/file/directory object. The canonical bytes use the versioned Heddle semantic index codec. The 32-byte hash uses Heddle’s Blob identity: BLAKE3(UTF8(“blob”) || uint64_le(canonical.length) || 0x00 || canonical), matching Blob::hash(). Hashing canonical alone is incorrect. This object grants no right to fetch other CAS objects.
Fields
hash: Vec<u8>canonical: Vec<u8>Trait Implementations
Sourceimpl Clone for SemanticIndexObject
impl Clone for SemanticIndexObject
Sourceimpl Debug for SemanticIndexObject
impl Debug for SemanticIndexObject
Sourceimpl Default for SemanticIndexObject
impl Default for SemanticIndexObject
impl Eq for SemanticIndexObject
Sourceimpl Hash for SemanticIndexObject
impl Hash for SemanticIndexObject
Sourceimpl Message for SemanticIndexObject
impl Message for SemanticIndexObject
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SemanticIndexObject
impl PartialEq for SemanticIndexObject
impl StructuralPartialEq for SemanticIndexObject