pub struct SetBookmarkRequest {
pub client_operation_id: String,
pub bookmark: Option<BookmarkRef>,
pub bookmarked: bool,
pub expected_version: Vec<u8>,
pub label: String,
}Fields
client_operation_id: Stringbookmark: Option<BookmarkRef>bookmarked: boolexpected_version: Vec<u8>Empty means no bookmark has ever existed; tombstones retain a version.
label: StringTrait Implementations
Sourceimpl Clone for SetBookmarkRequest
impl Clone for SetBookmarkRequest
Sourceimpl Debug for SetBookmarkRequest
impl Debug for SetBookmarkRequest
Sourceimpl Default for SetBookmarkRequest
impl Default for SetBookmarkRequest
impl Eq for SetBookmarkRequest
Sourceimpl Hash for SetBookmarkRequest
impl Hash for SetBookmarkRequest
Sourceimpl Message for SetBookmarkRequest
impl Message for SetBookmarkRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetBookmarkRequest
impl PartialEq for SetBookmarkRequest
impl StructuralPartialEq for SetBookmarkRequest