pub struct SpoolPages {
pub threads: Option<PageRequest>,
pub members: Option<PageRequest>,
pub invitations: Option<PageRequest>,
pub grants: Option<PageRequest>,
pub policies: Option<PageRequest>,
pub approval_groups: Option<PageRequest>,
pub context: Option<PageRequest>,
pub operations: Option<PageRequest>,
pub children: Option<PageRequest>,
pub support_access: Option<PageRequest>,
}Fields
threads: Option<PageRequest>members: Option<PageRequest>invitations: Option<PageRequest>grants: Option<PageRequest>policies: Option<PageRequest>approval_groups: Option<PageRequest>context: Option<PageRequest>operations: Option<PageRequest>children: Option<PageRequest>support_access: Option<PageRequest>Trait Implementations
Sourceimpl Clone for SpoolPages
impl Clone for SpoolPages
Sourceimpl Debug for SpoolPages
impl Debug for SpoolPages
Sourceimpl Default for SpoolPages
impl Default for SpoolPages
impl Eq for SpoolPages
Sourceimpl Hash for SpoolPages
impl Hash for SpoolPages
Sourceimpl Message for SpoolPages
impl Message for SpoolPages
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SpoolPages
impl PartialEq for SpoolPages
impl StructuralPartialEq for SpoolPages