pub struct StackLanding {
pub thread: Option<ThreadRef>,
pub source: Option<RevisionRef>,
pub target: Option<ThreadRef>,
pub expected_target: Option<RevisionRef>,
pub expected_policy_version: Vec<u8>,
}Expand description
Each source is the exact revision supplied by the caller. For every distinct target, expected_target is compared once against the initial transaction snapshot. Ordered members then integrate into that target’s evolving frontier.
Fields
thread: Option<ThreadRef>source: Option<RevisionRef>target: Option<ThreadRef>expected_target: Option<RevisionRef>expected_policy_version: Vec<u8>Trait Implementations
Sourceimpl Clone for StackLanding
impl Clone for StackLanding
Sourceimpl Debug for StackLanding
impl Debug for StackLanding
Sourceimpl Default for StackLanding
impl Default for StackLanding
impl Eq for StackLanding
Sourceimpl Hash for StackLanding
impl Hash for StackLanding
Sourceimpl Message for StackLanding
impl Message for StackLanding
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StackLanding
impl PartialEq for StackLanding
impl StructuralPartialEq for StackLanding