pub struct StreamCheckpoint {
pub cursor: Vec<u8>,
pub previous_cursor: Vec<u8>,
pub snapshot_complete: bool,
pub page: Option<PageInfo>,
}Fields
cursor: Vec<u8>The first checkpoint commits the staged snapshot. Later checkpoints commit a bounded batch of typed upserts/removals. Only committed cursors may resume.
previous_cursor: Vec<u8>Empty for a replacement snapshot; otherwise the last committed cursor.
snapshot_complete: boolpage: Option<PageInfo>Trait Implementations
Sourceimpl Clone for StreamCheckpoint
impl Clone for StreamCheckpoint
Sourceimpl Debug for StreamCheckpoint
impl Debug for StreamCheckpoint
Sourceimpl Default for StreamCheckpoint
impl Default for StreamCheckpoint
impl Eq for StreamCheckpoint
Sourceimpl Hash for StreamCheckpoint
impl Hash for StreamCheckpoint
Sourceimpl Message for StreamCheckpoint
impl Message for StreamCheckpoint
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StreamCheckpoint
impl PartialEq for StreamCheckpoint
impl StructuralPartialEq for StreamCheckpoint