pub struct ThreadPropertyFrontier {
pub property: i32,
pub record_id: String,
pub version: Vec<u8>,
pub operation_ids: Vec<Vec<u8>>,
}Fields
property: i32record_id: StringCanonical review UUID for REVIEW; empty for the singleton properties.
version: Vec<u8>operation_ids: Vec<Vec<u8>>Implementations
Sourceimpl ThreadPropertyFrontier
impl ThreadPropertyFrontier
Sourcepub fn property(&self) -> ThreadProperty
pub fn property(&self) -> ThreadProperty
Returns the enum value of property, or the default if the field is set to an invalid enum value.
Sourcepub fn set_property(&mut self, value: ThreadProperty)
pub fn set_property(&mut self, value: ThreadProperty)
Sets property to the provided enum value.