Module signing

Module signing 

Contract-owned request-signing bytes and header vocabulary.

Constants

DOMAIN
HEADER_ACTION_URL
HEADER_ALGORITHM
HEADER_IDENTITY
HEADER_NONCE_BIN
HEADER_REQUIRED
HEADER_SIGNATURE_BIN
HEADER_TIMESTAMP
HEADER_WEBAUTHN_AUTH_DATA_BIN
HEADER_WEBAUTHN_CLIENT_DATA_BIN
HEADER_WEBAUTHN_USER_HANDLE_BIN

Functions

retry_key_hash
Hashes the retry identity without conflating it with the request payload.
stream_open_bytes
Returns the canonical bytes signed by the opening frame of a stream.
unary_bytes
Returns the canonical bytes signed for a unary request.