Module treadle

Module treadle 

Canonical encoding for the signed treadle definition contract.

Enums

TreadleDefinitionError
Canonical treadle definition validation/decoding errors.

Constants

TREADLE_DEFINITION_FORMAT_VERSION
The only treadle definition format accepted by this release.

Functions

canonical_treadle_definition_bytes
Validate, normalize, and encode a definition using the v1 canonical wire rule.
decode_canonical_treadle_definition
Decode only a byte-exact canonical current-version definition.
treadle_definition_blake3
Return the BLAKE3 content address of the v1 canonical protobuf bytes.