pub struct MethodDescriptor {Show 16 fields
pub path: &'static str,
pub input: &'static str,
pub output: &'static str,
pub streaming: StreamingShape,
pub live_stream: bool,
pub effect: RpcEffect,
pub retry_behavior: RetryBehavior,
pub signing_tier: SigningTier,
pub authorization_access: AuthorizationAccess,
pub signing_identity: StableSigningIdentity,
pub authorization: AuthorizationPolicy,
pub client_operation_id_required: bool,
pub client_operation_id_field_number: Option<u32>,
pub maturity: ServiceMaturity,
pub deployment_targets: &'static [DeploymentTarget],
pub route: MethodRoute,
}Expand description
Generated transport-neutral method contract.
Fields
path: &'static strinput: &'static stroutput: &'static strstreaming: StreamingShapelive_stream: booleffect: RpcEffectretry_behavior: RetryBehaviorsigning_tier: SigningTiersigning_identity: StableSigningIdentityclient_operation_id_required: boolclient_operation_id_field_number: Option<u32>maturity: ServiceMaturitydeployment_targets: &'static [DeploymentTarget]route: MethodRouteImplementations
Sourceimpl MethodDescriptor
impl MethodDescriptor
Sourcepub const fn allows_zero_rtt(&self) -> bool
pub const fn allows_zero_rtt(&self) -> bool
Only safe reads can be sent on replayable 0-RTT connections.
Sourcepub fn client_operation_id<'a>(
&self,
request: &'a [u8],
) -> Result<Option<&'a str>, RequestMetadataError>
pub fn client_operation_id<'a>( &self, request: &'a [u8], ) -> Result<Option<&'a str>, RequestMetadataError>
Extract the operation ID for the transport context from the exact request bytes. Adapters must not maintain a second route/field-number inventory.