#[repr(i32)]pub enum Plan {
Unspecified = 0,
Free = 1,
Basic = 2,
Pro = 3,
Org = 4,
}Expand description
Billing plan tier. product_id → plan is mapped server-side by weft from
checked-in, fail-closed config; clients never assert a Plan on writes.
Variants
Implementations
Sourceimpl Plan
impl Plan
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.