#[repr(i32)]pub enum StateAttachmentAuthorizationClassification {
Unspecified = 0,
NotAuthoritative = 1,
MetadataSupersession = 2,
}Expand description
Generated consumers classify every attachment kind before accepting its transfer. Every current client-authored kind is authoritative metadata and therefore requires literal METADATA_SUPERSESSION in addition to its normal schema, provenance, integrity, ownership, and predecessor validation. A new enum value without a non-UNSPECIFIED option fails Rust and TypeScript generation, preventing a new metadata lane from bypassing authorization.
Variants
Implementations
Sourceimpl StateAttachmentAuthorizationClassification
impl StateAttachmentAuthorizationClassification
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of StateAttachmentAuthorizationClassification.
Sourcepub fn from_i32(
value: i32,
) -> Option<StateAttachmentAuthorizationClassification>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32( value: i32, ) -> Option<StateAttachmentAuthorizationClassification>
Use the TryFrom<i32> implementation instead
Converts an i32 to a StateAttachmentAuthorizationClassification, or None if value is not a valid variant.
Sourceimpl StateAttachmentAuthorizationClassification
impl StateAttachmentAuthorizationClassification
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.