pub struct ActorSummary {Show 20 fields
pub session_id: String,
pub thread: String,
pub path: Option<String>,
pub base_state: Option<StateId>,
pub started_at: Option<Timestamp>,
pub provider: Option<String>,
pub model: Option<String>,
pub status: String,
pub heddle_session_id: Option<String>,
pub harness: Option<String>,
pub thinking_level: Option<String>,
pub usage_summary: Option<UsageSummary>,
pub last_progress_at: Option<Timestamp>,
pub report_flush_state: Option<String>,
pub client_instance_id: Option<String>,
pub attach_reason: Option<String>,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub probe_source: Option<String>,
pub probe_confidence: Option<f32>,
}Fields
session_id: Stringthread: Stringpath: Option<String>base_state: Option<StateId>started_at: Option<Timestamp>provider: Option<String>model: Option<String>status: Stringheddle_session_id: Option<String>harness: Option<String>thinking_level: Option<String>usage_summary: Option<UsageSummary>last_progress_at: Option<Timestamp>report_flush_state: Option<String>client_instance_id: Option<String>attach_reason: Option<String>native_actor_key: Option<String>native_parent_actor_key: Option<String>probe_source: Option<String>probe_confidence: Option<f32>Implementations
Sourceimpl ActorSummary
impl ActorSummary
Sourcepub fn provider(&self) -> &str
pub fn provider(&self) -> &str
Returns the value of provider, or the default value if provider is unset.
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Returns the value of model, or the default value if model is unset.
Sourcepub fn heddle_session_id(&self) -> &str
pub fn heddle_session_id(&self) -> &str
Returns the value of heddle_session_id, or the default value if heddle_session_id is unset.
Sourcepub fn harness(&self) -> &str
pub fn harness(&self) -> &str
Returns the value of harness, or the default value if harness is unset.
Sourcepub fn thinking_level(&self) -> &str
pub fn thinking_level(&self) -> &str
Returns the value of thinking_level, or the default value if thinking_level is unset.
Sourcepub fn report_flush_state(&self) -> &str
pub fn report_flush_state(&self) -> &str
Returns the value of report_flush_state, or the default value if report_flush_state is unset.
Sourcepub fn client_instance_id(&self) -> &str
pub fn client_instance_id(&self) -> &str
Returns the value of client_instance_id, or the default value if client_instance_id is unset.
Sourcepub fn attach_reason(&self) -> &str
pub fn attach_reason(&self) -> &str
Returns the value of attach_reason, or the default value if attach_reason is unset.
Sourcepub fn native_actor_key(&self) -> &str
pub fn native_actor_key(&self) -> &str
Returns the value of native_actor_key, or the default value if native_actor_key is unset.
Sourcepub fn native_parent_actor_key(&self) -> &str
pub fn native_parent_actor_key(&self) -> &str
Returns the value of native_parent_actor_key, or the default value if native_parent_actor_key is unset.
Sourcepub fn probe_source(&self) -> &str
pub fn probe_source(&self) -> &str
Returns the value of probe_source, or the default value if probe_source is unset.
Sourcepub fn probe_confidence(&self) -> f32
pub fn probe_confidence(&self) -> f32
Returns the value of probe_confidence, or the default value if probe_confidence is unset.