pub struct AuthorizationVerificationKey {
pub algorithm: i32,
pub public_key: Vec<u8>,
}Fields
algorithm: i32public_key: Vec<u8>Exactly 32 raw Ed25519 public-key bytes in format version 1.
Implementations
Sourceimpl AuthorizationVerificationKey
impl AuthorizationVerificationKey
Sourcepub fn algorithm(&self) -> AuthorizationKeyAlgorithm
pub fn algorithm(&self) -> AuthorizationKeyAlgorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: AuthorizationKeyAlgorithm)
pub fn set_algorithm(&mut self, value: AuthorizationKeyAlgorithm)
Sets algorithm to the provided enum value.