pub struct CloneOwnerPin {
pub kind: i32,
pub expected_owner_id: Vec<u8>,
pub first_seen_unix_seconds: i64,
}Expand description
Local provenance chosen and persisted by the client. There is no UUID-to-key migration or legacy TOFU arm: all accounts start owner-anchored.
Fields
kind: i32expected_owner_id: Vec<u8>first_seen_unix_seconds: i64Implementations
Sourceimpl CloneOwnerPin
impl CloneOwnerPin
Sourcepub fn kind(&self) -> CloneOwnerPinKind
pub fn kind(&self) -> CloneOwnerPinKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CloneOwnerPinKind)
pub fn set_kind(&mut self, value: CloneOwnerPinKind)
Sets kind to the provided enum value.