pub struct CreateSpoolRequest {
pub parent_path: String,
pub slug: String,
pub is_repo: bool,
pub display_name: Option<String>,
pub visibility: i32,
pub client_operation_id: String,
}Fields
parent_path: Stringslug: Stringis_repo: booldisplay_name: Option<String>visibility: i32client_operation_id: StringImplementations
Sourceimpl CreateSpoolRequest
impl CreateSpoolRequest
Sourcepub fn display_name(&self) -> &str
pub fn display_name(&self) -> &str
Returns the value of display_name, or the default value if display_name is unset.
Sourcepub fn visibility(&self) -> SpoolVisibility
pub fn visibility(&self) -> SpoolVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: SpoolVisibility)
pub fn set_visibility(&mut self, value: SpoolVisibility)
Sets visibility to the provided enum value.