pub struct Discussion {Show 13 fields
pub id: String,
pub anchor: Option<PathSymbolRef>,
pub opened_against_state: Option<StateId>,
pub opened_at: Option<Timestamp>,
pub thread_ref: String,
pub turns: Vec<DiscussionTurn>,
pub resolution: Option<DiscussionResolution>,
pub body_changed_since_open: bool,
pub orphaned: bool,
pub visibility: String,
pub resolved_annotation_id: String,
pub thread_id: String,
pub severity: i32,
}Fields
id: Stringanchor: Option<PathSymbolRef>opened_against_state: Option<StateId>opened_at: Option<Timestamp>thread_ref: Stringturns: Vec<DiscussionTurn>resolution: Option<DiscussionResolution>body_changed_since_open: boolorphaned: boolvisibility: Stringresolved_annotation_id: Stringthread_id: StringStable identity paired with thread_ref.
severity: i32Actual value, no inference. UNSPECIFIED is treated as Informational (non-blocking); BLOCKING makes an open discussion an unmet merge requirement; a Reject sets Blocking.
Implementations
Sourceimpl Discussion
impl Discussion
Sourcepub fn severity(&self) -> DiscussionSeverity
pub fn severity(&self) -> DiscussionSeverity
Returns the enum value of severity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_severity(&mut self, value: DiscussionSeverity)
pub fn set_severity(&mut self, value: DiscussionSeverity)
Sets severity to the provided enum value.