pub struct OpenDiscussionRequest {
pub repo_path: Option<RepositoryRef>,
pub state_id: Option<StateId>,
pub anchor: Option<PathSymbolRef>,
pub body: String,
pub visibility: String,
pub thread_ref: String,
pub client_operation_id: String,
}Fields
repo_path: Option<RepositoryRef>state_id: Option<StateId>anchor: Option<PathSymbolRef>body: Stringvisibility: StringOptional override; empty uses the configured discussion visibility policy.
thread_ref: Stringclient_operation_id: StringTrait Implementations
Sourceimpl Clone for OpenDiscussionRequest
impl Clone for OpenDiscussionRequest
Sourcefn clone(&self) -> OpenDiscussionRequest
fn clone(&self) -> OpenDiscussionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenDiscussionRequest
impl Debug for OpenDiscussionRequest
Sourceimpl Default for OpenDiscussionRequest
impl Default for OpenDiscussionRequest
impl Eq for OpenDiscussionRequest
Sourceimpl Hash for OpenDiscussionRequest
impl Hash for OpenDiscussionRequest
Sourceimpl Message for OpenDiscussionRequest
impl Message for OpenDiscussionRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OpenDiscussionRequest
impl PartialEq for OpenDiscussionRequest
impl StructuralPartialEq for OpenDiscussionRequest