pub struct RpcContract {
pub signing_identity: i32,
pub signing_tier: i32,
pub effect: i32,
pub retry_behavior: i32,
pub client_operation_id_required: bool,
pub capability: i32,
pub authorization_access: i32,
pub authorization_role: i32,
pub authorization_scope_source: i32,
pub authorization_existence: i32,
pub authorization_request_targets: Vec<AuthorizationRequestTarget>,
pub authorization_multi_target: bool,
}Fields
signing_identity: i32signing_tier: i32effect: i32retry_behavior: i32client_operation_id_required: boolcapability: i32Every request field that selects an authorization guard target and the role required for that target. Every populated selector is guarded; request-derived scope sources require at least one target, while non-request scope sources prohibit targets.
True when the authorization rule deliberately has multiple request targets. Audits reject a mismatch so a multi-resource rule cannot silently collapse to one selector.
Implementations
Sourceimpl RpcContract
impl RpcContract
Sourcepub fn signing_identity(&self) -> StableSigningIdentity
pub fn signing_identity(&self) -> StableSigningIdentity
Returns the enum value of signing_identity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_signing_identity(&mut self, value: StableSigningIdentity)
pub fn set_signing_identity(&mut self, value: StableSigningIdentity)
Sets signing_identity to the provided enum value.
Sourcepub fn signing_tier(&self) -> SigningTier
pub fn signing_tier(&self) -> SigningTier
Returns the enum value of signing_tier, or the default if the field is set to an invalid enum value.
Sourcepub fn set_signing_tier(&mut self, value: SigningTier)
pub fn set_signing_tier(&mut self, value: SigningTier)
Sets signing_tier to the provided enum value.
Sourcepub fn effect(&self) -> RpcEffect
pub fn effect(&self) -> RpcEffect
Returns the enum value of effect, or the default if the field is set to an invalid enum value.
Sourcepub fn set_effect(&mut self, value: RpcEffect)
pub fn set_effect(&mut self, value: RpcEffect)
Sets effect to the provided enum value.
Sourcepub fn retry_behavior(&self) -> RetryBehavior
pub fn retry_behavior(&self) -> RetryBehavior
Returns the enum value of retry_behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_retry_behavior(&mut self, value: RetryBehavior)
pub fn set_retry_behavior(&mut self, value: RetryBehavior)
Sets retry_behavior to the provided enum value.
Sourcepub fn capability(&self) -> CapabilityArea
pub fn capability(&self) -> CapabilityArea
Returns the enum value of capability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_capability(&mut self, value: CapabilityArea)
pub fn set_capability(&mut self, value: CapabilityArea)
Sets capability to the provided enum value.
Returns the enum value of authorization_access, or the default if the field is set to an invalid enum value.
Sets authorization_access to the provided enum value.
Returns the enum value of authorization_role, or the default if the field is set to an invalid enum value.
Sets authorization_role to the provided enum value.
Returns the enum value of authorization_scope_source, or the default if the field is set to an invalid enum value.
Sets authorization_scope_source to the provided enum value.
Returns the enum value of authorization_existence, or the default if the field is set to an invalid enum value.
Sets authorization_existence to the provided enum value.