pub struct SpoolSettings {
pub visibility: i32,
pub default_state_visibility: i32,
pub bootstrap_kind: i32,
pub bootstrap_source: String,
pub write_policy: i32,
pub child_policy: i32,
pub initial_tooling: Option<SpoolInitialTooling>,
pub sync_behavior: i32,
pub bootstrap_sync_direction: i32,
pub description: String,
pub hold_lifecycle: i32,
}Fields
visibility: i32default_state_visibility: i32bootstrap_kind: i32bootstrap_source: Stringwrite_policy: i32child_policy: i32initial_tooling: Option<SpoolInitialTooling>sync_behavior: i32bootstrap_sync_direction: i32description: Stringhold_lifecycle: i32+weft#481: inheritable HOLD lifecycle policy
Implementations
Sourceimpl SpoolSettings
impl SpoolSettings
Sourcepub fn visibility(&self) -> SpoolVisibility
pub fn visibility(&self) -> SpoolVisibility
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: SpoolVisibility)
pub fn set_visibility(&mut self, value: SpoolVisibility)
Sets visibility to the provided enum value.
Sourcepub fn default_state_visibility(&self) -> SpoolStateVisibility
pub fn default_state_visibility(&self) -> SpoolStateVisibility
Returns the enum value of default_state_visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_default_state_visibility(&mut self, value: SpoolStateVisibility)
pub fn set_default_state_visibility(&mut self, value: SpoolStateVisibility)
Sets default_state_visibility to the provided enum value.
Sourcepub fn bootstrap_kind(&self) -> SpoolBootstrapKind
pub fn bootstrap_kind(&self) -> SpoolBootstrapKind
Returns the enum value of bootstrap_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_bootstrap_kind(&mut self, value: SpoolBootstrapKind)
pub fn set_bootstrap_kind(&mut self, value: SpoolBootstrapKind)
Sets bootstrap_kind to the provided enum value.
Sourcepub fn write_policy(&self) -> SpoolWritePolicy
pub fn write_policy(&self) -> SpoolWritePolicy
Returns the enum value of write_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_write_policy(&mut self, value: SpoolWritePolicy)
pub fn set_write_policy(&mut self, value: SpoolWritePolicy)
Sets write_policy to the provided enum value.
Sourcepub fn child_policy(&self) -> SpoolChildPolicy
pub fn child_policy(&self) -> SpoolChildPolicy
Returns the enum value of child_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_child_policy(&mut self, value: SpoolChildPolicy)
pub fn set_child_policy(&mut self, value: SpoolChildPolicy)
Sets child_policy to the provided enum value.
Sourcepub fn sync_behavior(&self) -> SpoolSyncBehavior
pub fn sync_behavior(&self) -> SpoolSyncBehavior
Returns the enum value of sync_behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sync_behavior(&mut self, value: SpoolSyncBehavior)
pub fn set_sync_behavior(&mut self, value: SpoolSyncBehavior)
Sets sync_behavior to the provided enum value.
Sourcepub fn bootstrap_sync_direction(&self) -> SpoolBootstrapSyncDirection
pub fn bootstrap_sync_direction(&self) -> SpoolBootstrapSyncDirection
Returns the enum value of bootstrap_sync_direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_bootstrap_sync_direction(
&mut self,
value: SpoolBootstrapSyncDirection,
)
pub fn set_bootstrap_sync_direction( &mut self, value: SpoolBootstrapSyncDirection, )
Sets bootstrap_sync_direction to the provided enum value.
Sourcepub fn hold_lifecycle(&self) -> SpoolHoldLifecycle
pub fn hold_lifecycle(&self) -> SpoolHoldLifecycle
Returns the enum value of hold_lifecycle, or the default if the field is set to an invalid enum value.
Sourcepub fn set_hold_lifecycle(&mut self, value: SpoolHoldLifecycle)
pub fn set_hold_lifecycle(&mut self, value: SpoolHoldLifecycle)
Sets hold_lifecycle to the provided enum value.