pub struct RetryImportSourceRequest {
pub client_operation_id: String,
pub original_operation: Option<RecordRef>,
pub expected_operation_version: Vec<u8>,
}Expand description
Retry a failed native source fetch/adoption into its original Thread. The original operation remains immutable; this command creates a new operation and never creates a second Spool or Thread genesis.
Fields
client_operation_id: Stringoriginal_operation: Option<RecordRef>expected_operation_version: Vec<u8>Trait Implementations
Sourceimpl Clone for RetryImportSourceRequest
impl Clone for RetryImportSourceRequest
Sourceimpl Debug for RetryImportSourceRequest
impl Debug for RetryImportSourceRequest
Sourceimpl Default for RetryImportSourceRequest
impl Default for RetryImportSourceRequest
impl Eq for RetryImportSourceRequest
Sourceimpl Hash for RetryImportSourceRequest
impl Hash for RetryImportSourceRequest
Sourceimpl Message for RetryImportSourceRequest
impl Message for RetryImportSourceRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RetryImportSourceRequest
impl PartialEq for RetryImportSourceRequest
impl StructuralPartialEq for RetryImportSourceRequest